@@ -27,8 +27,6 @@
 
 #include "bsocket.h"
 
-//#include "safedelete.h"
-
 //#define BS_DEBUG
 
 #ifdef BS_DEBUG
@@ -120,9 +118,9 @@ public:
     QString service;
     QString transport;
     QString domain;
-    quint16 port;
+    quint16 port = 0;
     QHostAddress address;
-    QAbstractSocket::NetworkLayerProtocol fallbackProtocol;
+    QAbstractSocket::NetworkLayerProtocol fallbackProtocol = QAbstractSocket::IPv4Protocol;
 
     /*! runtime data */
     QString lastError;
@@ -131,10 +129,8 @@ public:
     QTimer fallbackTimer;
 
     HappyEyeballsConnector(QObject *parent) :
-        QObject(parent),
-        port(0)
+        QObject(parent)
     {
-        fallbackProtocol = QAbstractSocket::IPv4Protocol;
         fallbackTimer.setSingleShot(true);
         fallbackTimer.setInterval(250); /* rfc recommends 150-250ms */
         connect(&fallbackTimer, SIGNAL(timeout()), SLOT(startFallback()));
@@ -232,7 +228,7 @@ public:
         csd.relay->setParent(parent);
         csd.sock->setParent(parent);
         delete csd.resolver; // FIME ensure it's accessible only from connected signal. we don't delete resolver from its slot
-        csd.resolver = 0;
+        csd.resolver = nullptr;
         return csd;
     }
 
@@ -404,8 +400,8 @@ class BSocket::Private
 public:
     Private()
     {
-        qsock = 0;
-        qsock_relay = 0;
+        qsock = nullptr;
+        qsock_relay = nullptr;
     }
 
     QTcpSocket *qsock;
@@ -417,8 +413,6 @@ public:
     QHostAddress address; //!< IP address we are currently connected to
     quint16 port; //!< Port we are currently connected to
 
-    //SafeDelete sd;
-
     QPointer<HappyEyeballsConnector> connector;
 };
 
@@ -447,11 +441,11 @@ void BSocket::resetConnection(bool clear)
 
     if(d->qsock) {
         delete d->qsock_relay;
-        d->qsock_relay = 0;
+        d->qsock_relay = nullptr;
 
         // move remaining into the local queue
         if (d->qsock->isOpen()) {
-            QByteArray block(d->qsock->bytesAvailable(), 0);
+            QByteArray block(int(d->qsock->bytesAvailable()), 0); // memory won't never be cheap enough to have gigabytes for socket buffer
             if (block.size()) {
                 d->qsock->read(block.data(), block.size());
                 appendRead(block);
@@ -461,7 +455,7 @@ void BSocket::resetConnection(bool clear)
 
         //d->sd.deleteLater(d->qsock);
         d->qsock->deleteLater();
-        d->qsock = 0;
+        d->qsock = nullptr;
     }
     else {
         if(clear)
@@ -525,7 +519,7 @@ QAbstractSocket* BSocket::abstractSocket() const
     return d->qsock;
 }
 
-int BSocket::socket() const
+qintptr BSocket::socket() const
 {
     if(d->qsock)
         return d->qsock->socketDescriptor();
@@ -589,9 +583,9 @@ qint64 BSocket::readData(char *data, qint64 maxSize)
     if(!maxSize) {
         return 0;
     }
-    quint64 readSize;
+    qint64 readSize;
     if(d->qsock) {
-        int max = bytesAvailable();
+        qint64 max = bytesAvailable();
         if(maxSize <= 0 || maxSize > max) {
             maxSize = max;
         }
@@ -674,7 +668,6 @@ void BSocket::qs_connected_step2(bool signalConnected)
 #ifdef BS_DEBUG
     BSDEBUG << "Connected";
 #endif
-    //SafeDeleteLock s(&d->sd);
     if (signalConnected) {
         emit connected();
     }
@@ -691,7 +684,6 @@ void BSocket::qs_closed()
 #ifdef BS_DEBUG
         BSDEBUG << "Delayed Close Finished";
 #endif
-        //SafeDeleteLock s(&d->sd);
         resetConnection();
         emit delayedCloseFinished();
     }
@@ -699,7 +691,6 @@ void BSocket::qs_closed()
 
 void BSocket::qs_readyRead()
 {
-    //SafeDeleteLock s(&d->sd);
     emit readyRead();
 }
 
@@ -709,7 +700,6 @@ void BSocket::qs_bytesWritten(qint64 x64)
 #ifdef BS_DEBUG_EXTRA
     BSDEBUG << "BytesWritten [" << x << "]";
 #endif
-    //SafeDeleteLock s(&d->sd);
     emit bytesWritten(x);
 }
 
@@ -719,7 +709,6 @@ void BSocket::qs_error(QAbstractSocket::SocketError x)
 #ifdef BS_DEBUG
         BSDEBUG << "Connection Closed";
 #endif
-        //SafeDeleteLock s(&d->sd);
         resetConnection();
         emit connectionClosed();
         return;
@@ -728,8 +717,6 @@ void BSocket::qs_error(QAbstractSocket::SocketError x)
 #ifdef BS_DEBUG
     BSDEBUG << "Error";
 #endif
-    //SafeDeleteLock s(&d->sd);
-
     resetConnection();
     if(x == QTcpSocket::ConnectionRefusedError)
         emit error(ErrConnectionRefused);
