@@ -88,6 +88,8 @@ StreamFeatures::StreamFeatures()
     tls_required = false;
     compress_supported = false;
     sm_supported = false;
+    session_supported = false;
+    session_required = false;
 }
 
 //----------------------------------------------------------------------------
@@ -96,9 +98,13 @@ StreamFeatures::StreamFeatures()
 BasicProtocol::SASLCondEntry BasicProtocol::saslCondTable[] =
 {
     { "aborted",                Aborted },
+    { "account-disabled",       AccountDisabled },
+    { "credentials-expired",    CredentialsExpired },
+    { "encryption-required",    EncryptionRequired },
     { "incorrect-encoding",     IncorrectEncoding },
     { "invalid-authzid",        InvalidAuthzid },
     { "invalid-mechanism",      InvalidMech },
+    { "malformed-request",      MalformedRequest },
     { "mechanism-too-weak",     MechTooWeak },
     { "not-authorized",         NotAuthorized },
     { "temporary-auth-failure", TemporaryAuthFailure },
@@ -119,8 +125,10 @@ BasicProtocol::StreamCondEntry BasicProtocol::streamCondTable[] =
     { "invalid-namespace",        InvalidNamespace },
     { "invalid-xml",              InvalidXml },
     { "not-authorized",           StreamNotAuthorized },
+    { "not-well-formed",          NotWellFormed },
     { "policy-violation",         PolicyViolation },
     { "remote-connection-failed", RemoteConnectionFailed },
+    { "reset",                    StreamReset },
     { "resource-constraint",      ResourceConstraint },
     { "restricted-xml",           RestrictedXml },
     { "see-other-host",           SeeOtherHost },
@@ -129,7 +137,6 @@ BasicProtocol::StreamCondEntry BasicProtocol::streamCondTable[] =
     { "unsupported-encoding",     UnsupportedEncoding },
     { "unsupported-stanza-type",  UnsupportedStanzaType },
     { "unsupported-version",      UnsupportedVersion },
-    { "not-well-formed",          NotWellFormed },
     { 0, 0 },
 };
 
@@ -197,6 +204,11 @@ void BasicProtocol::sendWhitespace()
     sendList += i;
 }
 
+void BasicProtocol::clearSendQueue()
+{
+    sendList.clear();
+}
+
 QDomElement BasicProtocol::recvStanza()
 {
     QDomElement e = stanzaToRecv;
@@ -295,6 +307,7 @@ QString BasicProtocol::streamCondToString(int x)
 void BasicProtocol::extractStreamError(const QDomElement &e)
 {
     QString text;
+    QHash<QString,QString> langText;
     QDomElement appSpec;
 
     QDomElement t = firstChildElement(e);
@@ -310,8 +323,14 @@ void BasicProtocol::extractStreamError(const QDomElement &e)
         if(errCond == SeeOtherHost)
             otherHost = t.text();
 
-        t = e.elementsByTagNameNS(NS_STREAMS, "text").item(0).toElement();
-        if(!t.isNull())
+        auto nodes = e.elementsByTagNameNS(NS_STREAMS, "text");
+        if (nodes.count()) {
+            for (int i = 0; i < nodes.count(); i++) {
+                auto e = nodes.item(i).toElement();
+                QString lang = e.attributeNS(NS_STREAMS, "lang", "");
+                langText.insert(lang, e.text());
+            }
+        } else
             text = t.text();
 
         // find first non-standard namespaced element
@@ -325,6 +344,7 @@ void BasicProtocol::extractStreamError(const QDomElement &e)
         }
 
         errText = text;
+        errLangText = langText;
         errAppSpec = appSpec;
     }
 }
@@ -1381,7 +1401,7 @@ bool CoreProtocol::normalStep(const QDomElement &e)
     }
     else if(step == GetFeatures) {
         // we are waiting for stream features
-        if(e.namespaceURI() == NS_ETHERX && e.tagName() == "features") {
+        if(e.namespaceURI() == NS_ETHERX && e.tagName() == QLatin1String("features")) {
             // extract features
             StreamFeatures f;
             QDomNodeList nl = e.childNodes();
@@ -1391,35 +1411,40 @@ bool CoreProtocol::normalStep(const QDomElement &e)
                 if (c.isNull()) {
                     continue;
                 }
-                if (c.localName() == "starttls" && c.namespaceURI() == NS_TLS) {
+                if (c.localName() == QLatin1String("starttls") && c.namespaceURI() == NS_TLS) {
                     f.tls_supported = true;
-                    f.tls_required = c.elementsByTagNameNS(NS_TLS, "required").count() > 0;
+                    f.tls_required = c.elementsByTagNameNS(NS_TLS, QLatin1String("required")).count() > 0;
 
-                } else if (c.localName() == "mechanisms" && c.namespaceURI() == NS_SASL) {
+                } else if (c.localName() == QLatin1String("mechanisms") && c.namespaceURI() == NS_SASL) {
                     f.sasl_supported = true;
-                    QDomNodeList l = c.elementsByTagNameNS(NS_SASL, "mechanism");
+                    QDomNodeList l = c.elementsByTagNameNS(NS_SASL, QLatin1String("mechanism"));
                     for(int n = 0; n < l.count(); ++n)
                         f.sasl_mechs += l.item(n).toElement().text();
 
-                } else if (c.localName() == "compression" && c.namespaceURI() == NS_COMPRESS_FEATURE) {
+                } else if (c.localName() == QLatin1String("compression") && c.namespaceURI() == NS_COMPRESS_FEATURE) {
                     f.compress_supported = true;
-                    QDomNodeList l = c.elementsByTagNameNS(NS_COMPRESS_FEATURE, "method");
+                    QDomNodeList l = c.elementsByTagNameNS(NS_COMPRESS_FEATURE, QLatin1String("method"));
                     for(int n = 0; n < l.count(); ++n)
                         f.compression_mechs += l.item(n).toElement().text();
 
-                } else if (c.localName() == "bind" && c.namespaceURI() == NS_BIND) {
+                } else if (c.localName() == QLatin1String("bind") && c.namespaceURI() == NS_BIND) {
                     f.bind_supported = true;
 
-                } else if (c.localName() == "hosts" && c.namespaceURI() == NS_HOSTS) {
-                    QDomNodeList l = c.elementsByTagNameNS(NS_HOSTS, "host");
+                } else if (c.localName() == QLatin1String("hosts") && c.namespaceURI() == NS_HOSTS) {
+                    QDomNodeList l = c.elementsByTagNameNS(NS_HOSTS, QLatin1String("host"));
                     for(int n = 0; n < l.count(); ++n)
                         f.hosts += l.item(n).toElement().text();
                     hosts += f.hosts;
 
-                } else if (c.localName() == "sm" && c.namespaceURI() == NS_STREAM_MANAGEMENT) {
+                } else if (c.localName() == QLatin1String("sm") && c.namespaceURI() == NS_STREAM_MANAGEMENT) {
                     f.sm_supported = true;
                     // REVIEW: previously we checked for sasl_authed as well. why?
 
+                } else if (c.localName() == QLatin1String("session") && c.namespaceURI() == NS_SESSION) {
+                    f.session_supported = true;
+                    f.session_required = c.elementsByTagName(QLatin1String("optional")).count() == 0;
+                    // more details https://tools.ietf.org/html/draft-cridland-xmpp-session-01
+
                 } else {
                     unhandled.append(c);
                 }
@@ -1554,6 +1579,16 @@ bool CoreProtocol::normalStep(const QDomElement &e)
                 else
                     errCond = stringToSASLCond(t.tagName());
 
+                // handle text elements
+                auto nodes = e.elementsByTagNameNS(NS_SASL, QLatin1String("text"));
+                decltype(errLangText) lt;
+                for (int i = 0; i < nodes.count(); i++) {
+                    auto e = nodes.item(i).toElement();
+                    QString lang = e.attributeNS(NS_SASL, "lang", "");
+                    lt.insert(lang, e.text());
+                }
+
+                errLangText = lt;
                 event = EError;
                 errorCode = ErrAuth;
                 return true;
@@ -1832,8 +1867,8 @@ bool CoreProtocol::normalStep(const QDomElement &e)
             } else if (e.localName() == "failed") {
                 if (sm.state().isResumption()) { // tried to resume? ok, then try to just enable
                     sm.state().resumption_id.clear();
-                    step = HandleFeatures;
-                    event = EFeatures;
+                    //step = HandleFeatures;
+                    event = ESMResumeFailed;
                     return true;
                 }
             }
