@@ -73,7 +73,6 @@
 #include <QList>
 
 #include "im.h"
-#include "safedelete.h"
 #include "xmpp_tasks.h"
 #include "xmpp_xmlcommon.h"
 #include "s5b.h"
@@ -81,7 +80,12 @@
 #include "xmpp_bitsofbinary.h"
 #include "filetransfer.h"
 #include "xmpp_caps.h"
+#include "xmpp_hash.h"
 #include "protocol.h"
+#include "xmpp_serverinfomanager.h"
+#include "httpfileupload.h"
+#include "jingle.h"
+#include "jingle-ft.h"
 
 #ifdef Q_OS_WIN
 #define vsnprintf _vsnprintf
@@ -99,10 +103,10 @@ class Client::GroupChat
 {
 public:
     enum { Connecting, Connected, Closing };
-    GroupChat() {}
+    GroupChat()  = default;
 
     Jid j;
-    int status;
+    int status = 0;
     QString password;
 };
 
@@ -113,28 +117,30 @@ public:
 
     QPointer<ClientStream> stream;
     QDomDocument doc;
-    int id_seed;
-    Task *root;
+    int id_seed = 0xaaaa;
+    Task *root = nullptr;
     QString host, user, pass, resource;
     QString osName, osVersion, tzname, clientName, clientVersion;
     CapsSpec caps, serverCaps;
     DiscoItem::Identity identity;
     Features features;
     QMap<QString,Features> extension_features;
-    int tzoffset;
-    bool useTzoffset;    // manual tzoffset is old way of doing utc<->local translations
-    bool active;
+    int tzoffset = 0;
+    bool useTzoffset = false;    // manual tzoffset is old way of doing utc<->local translations
+    bool active = false;
 
     LiveRoster roster;
     ResourceList resourceList;
-    CapsManager *capsman;
-    S5BManager *s5bman;
-    IBBManager *ibbman;
-    BoBManager *bobman;
-    FileTransferManager *ftman;
-    bool ftEnabled;
+    CapsManager *capsman = nullptr;
+    S5BManager *s5bman = nullptr;
+    IBBManager *ibbman = nullptr;
+    BoBManager *bobman = nullptr;
+    FileTransferManager *ftman = nullptr;
+    ServerInfoManager *serverInfoManager = nullptr;
+    HttpFileUploadManager *httpFileUploadManager = nullptr;
+    Jingle::Manager *jingleManager = nullptr;
     QList<GroupChat> groupChatList;
-    EncryptionHandler *encryptionHandler;
+    EncryptionHandler *encryptionHandler = nullptr;
 };
 
 
@@ -142,14 +148,11 @@ Client::Client(QObject *par)
 :QObject(par)
 {
     d = new ClientPrivate;
-    d->tzoffset = 0;
-    d->useTzoffset = false;
     d->active = false;
     d->osName = "N/A";
     d->clientName = "N/A";
     d->clientVersion = "0.0";
 
-    d->id_seed = 0xaaaa;
     d->root = new Task(this, true);
 
     d->s5bman = new S5BManager(this);
@@ -160,9 +163,15 @@ Client::Client(QObject *par)
 
     d->bobman = new BoBManager(this);
 
-    d->ftman = 0;
+    d->ftman = nullptr;
 
     d->capsman = new CapsManager(this);
+
+    d->serverInfoManager = new ServerInfoManager(this);
+    d->httpFileUploadManager = new HttpFileUploadManager(this);
+    d->jingleManager = new Jingle::Manager(this);
+    auto ft = new Jingle::FileTransfer::FTApplication(this);
+    d->jingleManager->registerApp(Jingle::FileTransfer::NS, ft);
 }
 
 Client::~Client()
@@ -263,6 +272,21 @@ CapsManager *Client::capsManager() const
     return d->capsman;
 }
 
+ServerInfoManager *Client::serverInfoManager() const
+{
+    return d->serverInfoManager;
+}
+
+HttpFileUploadManager *Client::httpFileUploadManager() const
+{
+    return d->httpFileUploadManager;
+}
+
+Jingle::Manager *Client::jingleManager() const
+{
+    return d->jingleManager;
+}
+
 bool Client::isActive() const
 {
     return d->active;
@@ -271,7 +295,7 @@ bool Client::isActive() const
 QString Client::groupChatPassword(const QString& host, const QString& room) const
 {
     Jid jid(room + "@" + host);
-    foreach(GroupChat i, d->groupChatList) {
+    foreach(const GroupChat &i, d->groupChatList) {
         if(i.j.compare(jid, false)) {
             return i.password;
         }
@@ -584,8 +608,9 @@ QDomDocument *Client::doc() const
 
 void Client::distribute(const QDomElement &x)
 {
-    if(x.hasAttribute("from")) {
-        Jid j(x.attribute("from"));
+    static QString fromAttr(QStringLiteral("from"));
+    if(x.hasAttribute(fromAttr)) {
+        Jid j(x.attribute(fromAttr));
         if(!j.isValid()) {
             debug("Client: bad 'from' JID\n");
             return;
@@ -956,7 +981,7 @@ void Client::slotRosterDelimiterRequestFinished()
 
 void Client::slotRosterRequestFinished()
 {
-    JT_Roster *r = (JT_Roster *)sender();
+    JT_Roster *r = static_cast<JT_Roster *>(sender());
     // on success, let's take it
     if(r->success()) {
         //d->roster.flagAllForDelete(); // mod_groups patch
@@ -1227,6 +1252,7 @@ DiscoItem Client::makeDiscoResult(const QString &node) const
     features.addFeature("urn:xmpp:ping");
     features.addFeature("urn:xmpp:time");
     features.addFeature("urn:xmpp:message-correct:0");
+    Hash::populateFeatures(features);
 
     // Client-specific features
     foreach (const QString & i, d->features.list()) {
