@@ -29,7 +29,6 @@
 #include "xmpp_xmlcommon.h"
 #include "im.h"
 #include "socks.h"
-#include "safedelete.h"
 
 #ifdef Q_OS_WIN
 # include <windows.h>
@@ -66,22 +65,28 @@ static bool haveHost(const StreamHostList &list, const Jid &j)
 class S5BManager::Item : public QObject
 {
     Q_OBJECT
+
 public:
     enum { Idle, Requester, Target, Active };
     enum { ErrRefused, ErrConnect, ErrWrongHost, ErrProxy };
     enum { Unknown, Fast, NotFast };
-    S5BManager *m;
-    int state;
+
+    S5BManager *m = nullptr;
+    int state = 0;
     QString sid, key, out_key, out_id, in_id;
     Jid self, peer;
     StreamHostList in_hosts;
-    JT_S5B *task, *proxy_task;
-    SocksClient *client, *client_out;
-    SocksUDP *client_udp, *client_out_udp;
-    S5BConnector *conn, *proxy_conn;
-    bool wantFast;
+    JT_S5B *task = nullptr;
+    JT_S5B *proxy_task = nullptr;
+    SocksClient *client = nullptr;
+    SocksClient *client_out = nullptr;
+    SocksUDP *client_udp = nullptr;
+    SocksUDP *client_out_udp = nullptr;
+    S5BConnector *conn = nullptr;
+    S5BConnector *proxy_conn = nullptr;
+    bool wantFast = false;
     StreamHost proxy;
-    int targetMode; // requester sets this once it figures it out
+    int targetMode = 0; // requester sets this once it figures it out
     bool fast; // target sets this
     bool activated;
     bool lateProxy;
@@ -89,7 +94,7 @@ public:
     bool localFailed, remoteFailed;
     bool allowIncoming;
     bool udp;
-    int statusCode;
+    int statusCode = 0;
     Jid activatedStream;
 
     Item(S5BManager *manager);
@@ -137,15 +142,13 @@ private:
 //----------------------------------------------------------------------------
 S5BDatagram::S5BDatagram()
 {
-    _source = 0;
-    _dest = 0;
 }
 
 S5BDatagram::S5BDatagram(int source, int dest, const QByteArray &data)
+    : _source(source)
+    , _dest(dest)
+    , _buf(data)
 {
-    _source = source;
-    _dest = dest;
-    _buf = data;
 }
 
 int S5BDatagram::sourcePort() const
@@ -545,28 +548,23 @@ void S5BConnection::sendUDP(const QByteArray &buf)
 class S5BManager::Entry
 {
 public:
-    Entry()
-    {
-        i = 0;
-        query = 0;
-        udp_init = false;
-    }
+    Entry() = default;
 
     ~Entry()
     {
         delete query;
     }
 
-    S5BConnection *c;
-    Item *i;
+    S5BConnection *c = nullptr;
+    Item *i = nullptr;
     QString sid;
-    JT_S5B *query;
+    JT_S5B *query = nullptr;
     StreamHost proxyInfo;
     QPointer<S5BServer> relatedServer;
 
-    bool udp_init;
+    bool udp_init = false;
     QHostAddress udp_addr;
-    int udp_port;
+    int udp_port = 0;
 };
 
 class S5BManager::Private
@@ -836,7 +834,7 @@ void S5BManager::srv_incomingReady(SocksClient *sc, const QString &key)
         sc->grantUDPAssociate("", 0);
     else
         sc->grantConnect();
-    e->relatedServer = (S5BServer *)sender();
+    e->relatedServer = static_cast<S5BServer *>(sender());
     e->i->setIncomingClient(sc);
 }
 
@@ -942,7 +940,7 @@ void S5BManager::con_sendUDP(S5BConnection *c, const QByteArray &buf)
 
 void S5BManager::item_accepted()
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     emit e->c->accepted(); // signal
@@ -950,7 +948,7 @@ void S5BManager::item_accepted()
 
 void S5BManager::item_tryingHosts(const StreamHostList &list)
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     e->c->tryingHosts(list); // signal
@@ -958,7 +956,7 @@ void S5BManager::item_tryingHosts(const StreamHostList &list)
 
 void S5BManager::item_proxyConnect()
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     e->c->proxyConnect(); // signal
@@ -966,7 +964,7 @@ void S5BManager::item_proxyConnect()
 
 void S5BManager::item_waitingForActivation()
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     e->c->waitingForActivation(); // signal
@@ -974,7 +972,7 @@ void S5BManager::item_waitingForActivation()
 
 void S5BManager::item_connected()
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     // grab the client
@@ -989,7 +987,7 @@ void S5BManager::item_connected()
 
 void S5BManager::item_error(int x)
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     Entry *e = findEntry(i);
 
     e->c->man_failed(x);
@@ -1035,7 +1033,7 @@ void S5BManager::queryProxy(Entry *e)
 
 void S5BManager::query_finished()
 {
-    JT_S5B *query = (JT_S5B *)sender();
+    JT_S5B *query = static_cast<JT_S5B *>(sender());
     Entry* e = 0;
     foreach(Entry* i, d->activeList) {
         if(i->query == query) {
@@ -1092,17 +1090,10 @@ bool S5BManager::targetShouldOfferProxy(Entry *e)
 //----------------------------------------------------------------------------
 // S5BManager::Item
 //----------------------------------------------------------------------------
-S5BManager::Item::Item(S5BManager *manager) : QObject(0)
+S5BManager::Item::Item(S5BManager *manager)
+    : QObject(nullptr)
+    , m(manager)
 {
-    m = manager;
-    task = 0;
-    proxy_task = 0;
-    conn = 0;
-    proxy_conn = 0;
-    client_udp = 0;
-    client = 0;
-    client_out_udp = 0;
-    client_out = 0;
     resetConnection();
 }
 
@@ -1114,28 +1105,28 @@ S5BManager::Item::~Item()
 void S5BManager::Item::resetConnection()
 {
     delete task;
-    task = 0;
+    task = nullptr;
 
     delete proxy_task;
-    proxy_task = 0;
+    proxy_task = nullptr;
 
     delete conn;
-    conn = 0;
+    conn = nullptr;
 
     delete proxy_conn;
-    proxy_conn = 0;
+    proxy_conn = nullptr;
 
     delete client_udp;
-    client_udp = 0;
+    client_udp = nullptr;
 
     delete client;
-    client = 0;
+    client = nullptr;
 
     delete client_out_udp;
-    client_out_udp = 0;
+    client_out_udp = nullptr;
 
     delete client_out;
-    client_out = 0;
+    client_out = nullptr;
 
     state = Idle;
     wantFast = false;
@@ -1753,14 +1744,16 @@ public:
     QTimer t;
     Jid jid;
 
-    Item(const Jid &self, const StreamHost &_host, const QString &_key, bool _udp) : QObject(0)
+    Item(const Jid &self, const StreamHost &_host, const QString &_key, bool _udp)
+        : QObject(0)
+        , client(new SocksClient)
+        , client_udp(0)
+        , host(_host)
+        , key(_key)
+        , udp(_udp)
+        , udp_tries(0)
+        , jid(self)
     {
-        jid = self;
-        host = _host;
-        key = _key;
-        udp = _udp;
-        client = new SocksClient;
-        client_udp = 0;
         connect(client, SIGNAL(connected()), SLOT(sc_connected()));
         connect(client, SIGNAL(error(int)), SLOT(sc_error(int)));
         connect(&t, SIGNAL(timeout()), SLOT(trySendUDP()));
@@ -1920,7 +1913,7 @@ StreamHost S5BConnector::streamHostUsed() const
 
 void S5BConnector::item_result(bool b)
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
     if(b) {
         d->active = i->client;
         i->client = 0;
@@ -2118,7 +2111,7 @@ void S5BServer::ss_incomingUDP(const QString &host, int port, const QHostAddress
 
 void S5BServer::item_result(bool b)
 {
-    Item *i = (Item *)sender();
+    Item *i = static_cast<Item *>(sender());
 #ifdef S5B_DEBUG
     qDebug("S5BServer item result: %d\n", b);
 #endif
