@@ -28,6 +28,7 @@
 #include "xmpp_ibb.h"
 #include "xmpp_captcha.h"
 #include "protocol.h"
+#include "xmpp/blake2/blake2qt.h"
 #define NS_XML     "http://www.w3.org/XML/1998/namespace"
 
 namespace XMPP
@@ -113,7 +114,7 @@ void Url::setDesc(const QString &desc)
     d->desc = desc;
 }
 
- //----------------------------------------------------------------------------
+//----------------------------------------------------------------------------
 // Address
 //----------------------------------------------------------------------------
 
@@ -124,15 +125,14 @@ void Url::setDesc(const QString &desc)
 //! \param Jid - specify address (default: empty string)
 //! \sa setType() setJid()
 Address::Address(Type type, const Jid & jid)
-: v_delivered(false)
+    : v_jid(jid)
+    , v_delivered(false)
+    , v_type(type)
 {
-    v_type = type;
-    v_jid = jid;
-    v_delivered = false;
 }
 
 Address::Address(const QDomElement& e)
-: v_delivered(false)
+    : v_delivered(false)
 {
     fromXml(e);
 }
@@ -177,33 +177,33 @@ QDomElement Address::toXml(Stanza& s) const
     if(delivered())
         e.setAttribute("delivered", "true");
     switch (type()) {
-        case To:
-            e.setAttribute("type", "to");
-            break;
-        case Cc:
-            e.setAttribute("type", "cc");
-            break;
-        case Bcc:
-            e.setAttribute("type", "bcc");
-            break;
-        case ReplyTo:
-            e.setAttribute("type", "replyto");
-            break;
-        case ReplyRoom:
-            e.setAttribute("type", "replyroom");
-            break;
-        case NoReply:
-            e.setAttribute("type", "noreply");
-            break;
-        case OriginalFrom:
-            e.setAttribute("type", "ofrom");
-            break;
-        case OriginalTo:
-            e.setAttribute("type", "oto");
-            break;
-        case Unknown:
-            // Add nothing
-            break;
+    case To:
+        e.setAttribute("type", "to");
+        break;
+    case Cc:
+        e.setAttribute("type", "cc");
+        break;
+    case Bcc:
+        e.setAttribute("type", "bcc");
+        break;
+    case ReplyTo:
+        e.setAttribute("type", "replyto");
+        break;
+    case ReplyRoom:
+        e.setAttribute("type", "replyroom");
+        break;
+    case NoReply:
+        e.setAttribute("type", "noreply");
+        break;
+    case OriginalFrom:
+        e.setAttribute("type", "ofrom");
+        break;
+    case OriginalTo:
+        e.setAttribute("type", "oto");
+        break;
+    case Unknown:
+        // Add nothing
+        break;
     }
     return e;
 }
@@ -310,6 +310,88 @@ void Address::setType(Type type)
     v_type = type;
 }
 
+
+//----------------------------------------------------------------------------
+// Hash
+//----------------------------------------------------------------------------
+static const struct {
+    const char *text;
+    Hash::Type hashType;
+} hashTypes[] =
+{
+{ "sha-1",       Hash::Type::Sha1 },
+{ "sha-256",     Hash::Type::Sha256 },
+{ "sha-512",     Hash::Type::Sha512 },
+{ "sha3-256",    Hash::Type::Sha3_256 },
+{ "sha3-512",    Hash::Type::Sha3_512 },
+{ "blake2b-256", Hash::Type::Blake2b256 },
+{ "blake2b-512", Hash::Type::Blake2b512 }
+};
+
+
+Hash::Hash(const QDomElement &el)
+{
+    QString algo = el.attribute(QLatin1String("algo"));
+    if (!algo.isEmpty()) {
+        for(size_t n = 0; n < sizeof(hashTypes) / sizeof(hashTypes[0]); ++n) {
+            if(algo == QLatin1String(hashTypes[n].text)) {
+                v_type = hashTypes[n].hashType;
+                if (el.tagName() == QLatin1String("hash")) {
+                    v_data = QByteArray::fromBase64(el.text().toLatin1());
+                    if (v_data.isEmpty()) {
+                        v_type = Type::Unknown;
+                    }
+                } // else hash-used
+                break;
+            }
+        }
+    }
+}
+
+bool Hash::computeFromData(const QByteArray &ba)
+{
+    v_data.clear();
+    switch (v_type) {
+    case Type::Sha1:     v_data = QCryptographicHash::hash(ba, QCryptographicHash::Sha1); break;
+    case Type::Sha256:   v_data = QCryptographicHash::hash(ba, QCryptographicHash::Sha256); break;
+    case Type::Sha512:   v_data = QCryptographicHash::hash(ba, QCryptographicHash::Sha512); break;
+    case Type::Sha3_256: v_data = QCryptographicHash::hash(ba, QCryptographicHash::Sha3_256); break;
+    case Type::Sha3_512: v_data = QCryptographicHash::hash(ba, QCryptographicHash::Sha3_512); break;
+    case Type::Blake2b256: v_data = computeBlake2Hash(ba, Blake2Digest256); break;
+    case Type::Blake2b512: v_data = computeBlake2Hash(ba, Blake2Digest512); break;
+    case Type::Unknown:
+    default:
+        qDebug("invalid hash type");
+        return false;
+    }
+    return !v_data.isEmpty();
+}
+
+QDomElement Hash::toXml(Stanza &s) const
+{
+    if (v_type != Type::Unknown) {
+        for(size_t n = 0; n < sizeof(hashTypes) / sizeof(hashTypes[0]); ++n) {
+            if(v_type == hashTypes[n].hashType) {
+                auto el = s.createElement(XMPP_HASH_NS, QLatin1String(v_data.isEmpty()? "hash-used": "hash"));
+                el.setAttribute(QLatin1String("algo"), QLatin1String(hashTypes[n].text));
+                if (!v_data.isEmpty()) {
+                    XMLHelper::setTagText(el, v_data.toBase64());
+                }
+                return el;
+            }
+        }
+    }
+    return QDomElement();
+}
+
+void Hash::populateFeatures(Features &features)
+{
+    for(size_t n = 0; n < sizeof(hashTypes) / sizeof(hashTypes[0]); ++n) {
+        features.addFeature(QLatin1String("urn:xmpp:hash-function-text-names:") +
+                            QLatin1String(hashTypes[n].text));
+    }
+}
+
 //----------------------------------------------------------------------------
 // RosterExchangeItem
 //----------------------------------------------------------------------------
@@ -375,15 +457,15 @@ QDomElement RosterExchangeItem::toXml(Stanza& s) const
     if (!name().isEmpty())
         e.setAttribute("name", name());
     switch(action()) {
-        case Add:
-            e.setAttribute("action","add");
-            break;
-        case Delete:
-            e.setAttribute("action","delete");
-            break;
-        case Modify:
-            e.setAttribute("action","modify");
-            break;
+    case Add:
+        e.setAttribute("action","add");
+        break;
+    case Delete:
+        e.setAttribute("action","delete");
+        break;
+    case Modify:
+        e.setAttribute("action","modify");
+        break;
     }
     foreach(QString group, groups_) {
         e.appendChild(s.createTextElement("http://jabber.org/protocol/rosterx", "group",group));
@@ -551,39 +633,39 @@ QDomElement MUCItem::toXml(QDomDocument& d)
         e.appendChild(textTag(&d,"reason",reason_));
 
     switch (affiliation_) {
-        case NoAffiliation:
-            e.setAttribute("affiliation","none");
-            break;
-        case Owner:
-            e.setAttribute("affiliation","owner");
-            break;
-        case Admin:
-            e.setAttribute("affiliation","admin");
-            break;
-        case Member:
-            e.setAttribute("affiliation","member");
-            break;
-        case Outcast:
-            e.setAttribute("affiliation","outcast");
-            break;
-        default:
-            break;
+    case NoAffiliation:
+        e.setAttribute("affiliation","none");
+        break;
+    case Owner:
+        e.setAttribute("affiliation","owner");
+        break;
+    case Admin:
+        e.setAttribute("affiliation","admin");
+        break;
+    case Member:
+        e.setAttribute("affiliation","member");
+        break;
+    case Outcast:
+        e.setAttribute("affiliation","outcast");
+        break;
+    default:
+        break;
     }
     switch (role_) {
-        case NoRole:
-            e.setAttribute("role","none");
-            break;
-        case Moderator:
-            e.setAttribute("role","moderator");
-            break;
-        case Participant:
-            e.setAttribute("role","participant");
-            break;
-        case Visitor:
-            e.setAttribute("role","visitor");
-            break;
-        default:
-            break;
+    case NoRole:
+        e.setAttribute("role","none");
+        break;
+    case Moderator:
+        e.setAttribute("role","moderator");
+        break;
+    case Participant:
+        e.setAttribute("role","participant");
+        break;
+    case Visitor:
+        e.setAttribute("role","visitor");
+        break;
+    default:
+        break;
     }
 
     return e;
@@ -664,7 +746,7 @@ void MUCInvite::fromXml(const QDomElement& e)
             continue;
 
         if (i.tagName() == "continue")
-           cont_ = true;
+            cont_ = true;
         else if (i.tagName() == "reason")
             reason_ = i.text();
     }
@@ -970,7 +1052,10 @@ public:
     //XEP-0280 Message Carbons
     bool isDisabledCarbons = false;
     Message::CarbonDir carbonDir = Message::NoCarbon; // it's a forwarded message
+    Message::ProcessingHints processingHints;
     QString replaceId;
+    QString originId; // XEP-0359
+    Message::StanzaId stanzaId; // XEP-0359
 };
 
 //! \brief Constructs Message with given Jid information.
@@ -978,8 +1063,8 @@ public:
 //! This function will construct a Message container.
 //! \param to - specify receiver (default: empty string)
 Message::Message(const Jid &to)
+    : d(new Private)
 {
-    d = new Private;
     d->to = to;
 }
 
@@ -1424,6 +1509,26 @@ bool Message::hasMUCUser() const
     return d->hasMUCUser;
 }
 
+Message::StanzaId Message::stanzaId() const
+{
+    return d->stanzaId;
+}
+
+void Message::setStanzaId(const Message::StanzaId &id)
+{
+    d->stanzaId = id;
+}
+
+QString Message::originId() const
+{
+    return d->originId;
+}
+
+void Message::setOriginId(const QString &id)
+{
+    d->originId = id;
+}
+
 QString Message::invite() const
 {
     return d->invite;
@@ -1547,6 +1652,16 @@ void Message::setReplaceId(const QString& id) {
     d->replaceId = id;
 }
 
+void Message::setProcessingHints(const ProcessingHints &hints)
+{
+    d->processingHints = hints;
+}
+
+Message::ProcessingHints Message::processingHints() const
+{
+    return d->processingHints;
+}
+
 Stanza Message::toStanza(Stream *stream) const
 {
     Stanza s = stream->createStanza(Stanza::Message, d->to, d->type);
@@ -1627,21 +1742,21 @@ Stanza Message::toStanza(Stream *stream) const
 
         foreach (const MsgEvent& ev, d->eventList) {
             switch (ev) {
-                case OfflineEvent:
-                    x.appendChild(s.createElement("jabber:x:event", "offline"));
-                    break;
-                case DeliveredEvent:
-                    x.appendChild(s.createElement("jabber:x:event", "delivered"));
-                    break;
-                case DisplayedEvent:
-                    x.appendChild(s.createElement("jabber:x:event", "displayed"));
-                    break;
-                case ComposingEvent:
-                    x.appendChild(s.createElement("jabber:x:event", "composing"));
-                    break;
-                case CancelEvent:
-                    // Add nothing
-                    break;
+            case OfflineEvent:
+                x.appendChild(s.createElement("jabber:x:event", "offline"));
+                break;
+            case DeliveredEvent:
+                x.appendChild(s.createElement("jabber:x:event", "delivered"));
+                break;
+            case DisplayedEvent:
+                x.appendChild(s.createElement("jabber:x:event", "displayed"));
+                break;
+            case ComposingEvent:
+                x.appendChild(s.createElement("jabber:x:event", "composing"));
+                break;
+            case CancelEvent:
+                // Add nothing
+                break;
             }
         }
         s.appendChild(x);
@@ -1651,23 +1766,23 @@ Stanza Message::toStanza(Stream *stream) const
     QString chatStateNS = "http://jabber.org/protocol/chatstates";
     if (d->chatState != StateNone) {
         switch(d->chatState) {
-            case StateActive:
-                s.appendChild(s.createElement(chatStateNS, "active"));
-                break;
-            case StateComposing:
-                s.appendChild(s.createElement(chatStateNS, "composing"));
-                break;
-            case StatePaused:
-                s.appendChild(s.createElement(chatStateNS, "paused"));
-                break;
-            case StateInactive:
-                s.appendChild(s.createElement(chatStateNS, "inactive"));
-                break;
-            case StateGone:
-                s.appendChild(s.createElement(chatStateNS, "gone"));
-                break;
-            default:
-                break;
+        case StateActive:
+            s.appendChild(s.createElement(chatStateNS, "active"));
+            break;
+        case StateComposing:
+            s.appendChild(s.createElement(chatStateNS, "composing"));
+            break;
+        case StatePaused:
+            s.appendChild(s.createElement(chatStateNS, "paused"));
+            break;
+        case StateInactive:
+            s.appendChild(s.createElement(chatStateNS, "inactive"));
+            break;
+        case StateGone:
+            s.appendChild(s.createElement(chatStateNS, "gone"));
+            break;
+        default:
+            break;
         }
     }
 
@@ -1675,20 +1790,20 @@ Stanza Message::toStanza(Stream *stream) const
     QString messageReceiptNS = "urn:xmpp:receipts";
     if (d->messageReceipt != ReceiptNone) {
         switch(d->messageReceipt) {
-            case ReceiptRequest:
-                s.appendChild(s.createElement(messageReceiptNS, "request"));
-                break;
-            case ReceiptReceived:
-                {
-                    QDomElement elem = s.createElement(messageReceiptNS, "received");
-                    if (!d->messageReceiptId.isEmpty()) {
-                        elem.setAttribute("id", d->messageReceiptId);
-                    }
-                    s.appendChild(elem);
-                }
-                break;
-            default:
-                break;
+        case ReceiptRequest:
+            s.appendChild(s.createElement(messageReceiptNS, "request"));
+            break;
+        case ReceiptReceived:
+        {
+            QDomElement elem = s.createElement(messageReceiptNS, "received");
+            if (!d->messageReceiptId.isEmpty()) {
+                elem.setAttribute("id", d->messageReceiptId);
+            }
+            s.appendChild(elem);
+        }
+            break;
+        default:
+            break;
         }
     }
 
@@ -1782,6 +1897,37 @@ Stanza Message::toStanza(Stream *stream) const
         e.setAttribute("id", d->replaceId);
         s.appendChild(e);
     }
+
+    // Message processing hints. XEP-0334
+    if (d->processingHints) {
+        QString ns = QStringLiteral(u"urn:xmpp:hints");
+        if (d->processingHints & NoPermanentStore) {
+            s.appendChild(s.createElement(ns, QStringLiteral("no-permanent-store")));
+        }
+        if (d->processingHints & NoStore) {
+            s.appendChild(s.createElement(ns, QStringLiteral("no-store")));
+        }
+        if (d->processingHints & NoCopy) {
+            s.appendChild(s.createElement(ns, QStringLiteral("no-copy")));
+        }
+        if (d->processingHints & Store) {
+            s.appendChild(s.createElement(ns, QStringLiteral("store")));
+        }
+    }
+
+    // XEP-0359: Unique and Stable Stanza IDs
+    if (!d->originId.isEmpty()) {
+        auto e = s.createElement(QStringLiteral("urn:xmpp:sid:0"), QStringLiteral("origin-id"));
+        e.setAttribute(QStringLiteral("id"), d->originId);
+        s.appendChild(e);
+    }
+    if (!d->stanzaId.id.isEmpty() && d->stanzaId.by.isValid()) { // only for servers using iris
+        auto e = s.createElement(QStringLiteral("urn:xmpp:sid:0"), QStringLiteral("stanza-id"));
+        e.setAttribute(QStringLiteral("id"), d->stanzaId.id);
+        e.setAttribute(QStringLiteral("by"), d->stanzaId.by.full());
+        s.appendChild(e);
+    }
+
     return s;
 }
 
@@ -1834,29 +1980,29 @@ bool Message::fromStanza(const Stanza &s, bool useTimeZoneOffset, int timeZoneOf
         if(i.isElement()) {
             QDomElement e = i.toElement();
             if(e.namespaceURI() == s.baseNS()) {
-                if(e.tagName() == "subject") {
+                if(e.tagName() == QLatin1String("subject")) {
                     QString lang = e.attributeNS(NS_XML, "lang", "");
                     if (lang.isEmpty() || !(lang = XMLHelper::sanitizedLang(lang)).isEmpty()) {
                         d->subject[lang] = e.text();
                     }
                 }
-                else if(e.tagName() == "body") {
+                else if(e.tagName() == QLatin1String("body")) {
                     QString lang = e.attributeNS(NS_XML, "lang", "");
                     if (lang.isEmpty() || !(lang = XMLHelper::sanitizedLang(lang)).isEmpty()) {
                         d->body[lang] = e.text();
                     }
                 }
-                else if(e.tagName() == "thread")
+                else if(e.tagName() == QLatin1String("thread"))
                     d->thread = e.text();
             }
-            else if(e.tagName() == "event" && e.namespaceURI() == "http://jabber.org/protocol/pubsub#event") {
+            else if(e.tagName() == QLatin1String("event") && e.namespaceURI() == QLatin1String("http://jabber.org/protocol/pubsub#event")) {
                 for(QDomNode enode = e.firstChild(); !enode.isNull(); enode = enode.nextSibling()) {
                     QDomElement eel = enode.toElement();
-                    if (eel.tagName() == "items") {
+                    if (eel.tagName() == QLatin1String("items")) {
                         d->pubsubNode = eel.attribute("node");
                         for(QDomNode inode = eel.firstChild(); !inode.isNull(); inode = inode.nextSibling()) {
                             QDomElement o = inode.toElement();
-                            if (o.tagName() == "item") {
+                            if (o.tagName() == QLatin1String("item")) {
                                 for(QDomNode j = o.firstChild(); !j.isNull(); j = j.nextSibling()) {
                                     QDomElement item = j.toElement();
                                     if (!item.isNull()) {
@@ -1871,6 +2017,26 @@ bool Message::fromStanza(const Stanza &s, bool useTimeZoneOffset, int timeZoneOf
                     }
                 }
             }
+            else if (e.tagName() == QLatin1String("no-permanent-store") && e.namespaceURI() == QLatin1String("urn:xmpp:hints")) {
+                d->processingHints |= NoPermanentStore;
+            }
+            else if (e.tagName() == QLatin1String("no-store") && e.namespaceURI() == QLatin1String("urn:xmpp:hints")) {
+                d->processingHints |= NoStore;
+            }
+            else if (e.tagName() == QLatin1String("no-copy") && e.namespaceURI() == QLatin1String("urn:xmpp:hints")) {
+                d->processingHints |= NoCopy;
+            }
+            else if (e.tagName() == QLatin1String("store") && e.namespaceURI() == QLatin1String("urn:xmpp:hints")) {
+                d->processingHints |= Store;
+            }
+            else if (e.tagName() == QLatin1String("origin-id") && e.namespaceURI() == QLatin1String("urn:xmpp:sid:0")) {
+                d->originId = e.attribute(QStringLiteral("id"));
+            }
+            else if (e.tagName() == QLatin1String("stanza-id") && e.namespaceURI() == QLatin1String("urn:xmpp:sid:0")) {
+                d->stanzaId.id = e.attribute(QStringLiteral("id"));
+                d->stanzaId.by = Jid(e.attribute(QStringLiteral("by")));
+            }
+
             else {
                 //printf("extension element: [%s]\n", e.tagName().latin1());
             }
@@ -2087,7 +2253,7 @@ bool Message::fromStanza(const Stanza &s, bool useTimeZoneOffset, int timeZoneOf
     }
 
     QDomElement captcha = childElementsByTagNameNS(root, "urn:xmpp:captcha",
-                                                 "captcha").item(0).toElement();
+                                                   "captcha").item(0).toElement();
     QDomElement xdataRoot = root;
     if (!captcha.isNull()) {
         xdataRoot = captcha;
@@ -2258,17 +2424,17 @@ int Subscription::type() const
 QString Subscription::toString() const
 {
     switch(value) {
-        case Remove:
-            return "remove";
-        case Both:
-            return "both";
-        case From:
-            return "from";
-        case To:
-            return "to";
-        case None:
-        default:
-            return "none";
+    case Remove:
+        return "remove";
+    case Both:
+        return "both";
+    case From:
+        return "from";
+    case To:
+        return "to";
+    case None:
+    default:
+        return "none";
     }
 }
 
@@ -2392,12 +2558,10 @@ CapsSpec::CryptoMap &CapsSpec::cryptoMap()
     if (cm.isEmpty()) {
         cm.insert("md5",     QCryptographicHash::Md5);
         cm.insert("sha-1",   QCryptographicHash::Sha1);
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
         cm.insert("sha-224", QCryptographicHash::Sha224);
         cm.insert("sha-256", QCryptographicHash::Sha256);
         cm.insert("sha-384", QCryptographicHash::Sha384);
         cm.insert("sha-512", QCryptographicHash::Sha512);
-#endif
     }
     return cm;
 }
@@ -2439,32 +2603,23 @@ bool CapsSpec::operator!=(const CapsSpec& s) const
 bool CapsSpec::operator<(const CapsSpec& s) const
 {
     return (node() != s.node() ? node() < s.node() :
-            (version() != s.version() ? version() < s.version() :
-             hashAlgorithm() < s.hashAlgorithm()));
+                                 (version() != s.version() ? version() < s.version() :
+                                                             hashAlgorithm() < s.hashAlgorithm()));
 }
 
 
 class StatusPrivate : public QSharedData
 {
 public:
-    StatusPrivate() :
-        hasPhotoHash(false),
-        isMUC(false),
-        hasMUCItem(false),
-        hasMUCDestroy(false),
-        mucHistoryMaxChars(-1),
-        mucHistoryMaxStanzas(-1),
-        mucHistorySeconds(-1),
-        ecode(-1)
-    {}
+    StatusPrivate() = default;
 
-    int priority;
+    int priority = 0;
     QString show, status, key;
     QDateTime timeStamp;
-    bool isAvailable;
-    bool isInvisible;
+    bool isAvailable = false;
+    bool isInvisible = false;
     QString photoHash;
-    bool hasPhotoHash;
+    bool hasPhotoHash = false;
 
     QString xsigned;
     // gabber song extension
@@ -2473,23 +2628,26 @@ public:
     QList<BoBData> bobDataList;
 
     // MUC
-    bool isMUC, hasMUCItem, hasMUCDestroy;
+    bool isMUC = false;
+    bool hasMUCItem = false;
+    bool hasMUCDestroy = false;
     MUCItem mucItem;
     MUCDestroy mucDestroy;
     QList<int> mucStatuses;
     QString mucPassword;
-    int mucHistoryMaxChars, mucHistoryMaxStanzas, mucHistorySeconds;
+    int mucHistoryMaxChars = -1;
+    int mucHistoryMaxStanzas = -1;
+    int mucHistorySeconds = -1;
     QDateTime mucHistorySince;
 
-    int ecode;
+    int ecode = -1;
     QString estr;
 };
 
 
 Status::Status(const QString &show, const QString &status, int priority, bool available)
+    : d(new StatusPrivate)
 {
-    d = new StatusPrivate;
-
     d->isAvailable = available;
     d->show = show;
     d->status = status;
@@ -2499,9 +2657,8 @@ Status::Status(const QString &show, const QString &status, int priority, bool av
 }
 
 Status::Status(Type type, const QString& status, int priority)
+    : d(new StatusPrivate)
 {
-    d = new StatusPrivate;
-
     d->status = status;
     d->priority = priority;
     d->timeStamp = QDateTime::currentDateTime();
@@ -2555,13 +2712,13 @@ void Status::setType(Status::Type _type)
     bool invisible = false;
     QString show;
     switch(_type) {
-        case Away:    show = "away"; break;
-        case FFC:     show = "chat"; break;
-        case XA:      show = "xa"; break;
-        case DND:     show = "dnd"; break;
-        case Offline: available = false; break;
-        case Invisible: invisible = true; break;
-        default: break;
+    case Away:    show = "away"; break;
+    case FFC:     show = "chat"; break;
+    case XA:      show = "xa"; break;
+    case DND:     show = "dnd"; break;
+    case Offline: available = false; break;
+    case Invisible: invisible = true; break;
+    default: break;
     }
     setShow(show);
     setIsAvailable(available);
@@ -2570,27 +2727,27 @@ void Status::setType(Status::Type _type)
 
 Status::Type Status::txt2type(const QString& stat)
 {
-      if (stat == "offline")
-              return XMPP::Status::Offline;
-      else if (stat == "online")
-              return XMPP::Status::Online;
-      else if (stat == "away")
-              return XMPP::Status::Away;
-      else if (stat == "xa")
-              return XMPP::Status::XA;
-      else if (stat == "dnd")
-              return XMPP::Status::DND;
-      else if (stat == "invisible")
-              return XMPP::Status::Invisible;
-      else if (stat == "chat")
-              return XMPP::Status::FFC;
-      else
-              return XMPP::Status::Away;
+    if (stat == "offline")
+        return XMPP::Status::Offline;
+    else if (stat == "online")
+        return XMPP::Status::Online;
+    else if (stat == "away")
+        return XMPP::Status::Away;
+    else if (stat == "xa")
+        return XMPP::Status::XA;
+    else if (stat == "dnd")
+        return XMPP::Status::DND;
+    else if (stat == "invisible")
+        return XMPP::Status::Invisible;
+    else if (stat == "chat")
+        return XMPP::Status::FFC;
+    else
+        return XMPP::Status::Away;
 }
 
-void Status::setType(QString stat)
+void Status::setType(const QString &stat)
 {
-      setType(txt2type(stat));
+    setType(txt2type(stat));
 }
 
 void Status::setShow(const QString & _show)
@@ -2714,9 +2871,9 @@ Status::Type Status::type() const
         if (s == "away")
             type = Status::Away;
         else if (s == "xa")
-              type = Status::XA;
+            type = Status::XA;
         else if (s == "dnd")
-             type = Status::DND;
+            type = Status::DND;
         else if (s == "chat")
             type = Status::FFC;
     }
@@ -2727,14 +2884,14 @@ QString Status::typeString() const
 {
     QString stat;
     switch(type()) {
-        case XMPP::Status::Offline: stat = "offline"; break;
-        case XMPP::Status::Online: stat = "online"; break;
-        case XMPP::Status::Away: stat = "away"; break;
-        case XMPP::Status::XA: stat = "xa"; break;
-        case XMPP::Status::DND: stat = "dnd"; break;
-        case XMPP::Status::Invisible: stat = "invisible"; break;
-        case XMPP::Status::FFC: stat = "chat"; break;
-        default: stat = "away";
+    case XMPP::Status::Offline: stat = "offline"; break;
+    case XMPP::Status::Online: stat = "online"; break;
+    case XMPP::Status::Away: stat = "away"; break;
+    case XMPP::Status::XA: stat = "xa"; break;
+    case XMPP::Status::DND: stat = "dnd"; break;
+    case XMPP::Status::Invisible: stat = "invisible"; break;
+    case XMPP::Status::FFC: stat = "chat"; break;
+    default: stat = "away";
     }
     return stat;
 }
@@ -2858,12 +3015,8 @@ const QString & Status::errorString() const
 // Resource
 //---------------------------------------------------------------------------
 Resource::Resource(const QString &name, const Status &stat)
-{
-    v_name = name;
-    v_status = stat;
-}
-
-Resource::~Resource()
+    : v_name(name)
+    , v_status(stat)
 {
 }
 
@@ -2897,7 +3050,7 @@ void Resource::setStatus(const Status & _status)
 // ResourceList
 //---------------------------------------------------------------------------
 ResourceList::ResourceList()
-:QList<Resource>()
+    :QList<Resource>()
 {
 }
 
@@ -2953,10 +3106,20 @@ ResourceList::ConstIterator ResourceList::priority() const
 //---------------------------------------------------------------------------
 // RosterItem
 //---------------------------------------------------------------------------
-RosterItem::RosterItem(const Jid &_jid)
+RosterItem::RosterItem(const Jid &_jid) :
+    v_jid(_jid),
+    v_push(false)
+{
+}
+
+RosterItem::RosterItem(const RosterItem &item) :
+    v_jid(item.v_jid),
+    v_name(item.v_name),
+    v_groups(item.v_groups),
+    v_subscription(item.v_subscription),
+    v_ask(item.v_ask),
+    v_push(item.v_push)
 {
-    v_jid = _jid;
-    v_push = false;
 }
 
 RosterItem::~RosterItem()
@@ -3198,22 +3361,22 @@ QString FormField::realName() const
 QString FormField::fieldName() const
 {
     switch(v_type) {
-        case username:  return QObject::tr("Username");
-        case nick:      return QObject::tr("Nickname");
-        case password:  return QObject::tr("Password");
-        case name:      return QObject::tr("Name");
-        case first:     return QObject::tr("First Name");
-        case last:      return QObject::tr("Last Name");
-        case email:     return QObject::tr("E-mail");
-        case address:   return QObject::tr("Address");
-        case city:      return QObject::tr("City");
-        case state:     return QObject::tr("State");
-        case zip:       return QObject::tr("Zipcode");
-        case phone:     return QObject::tr("Phone");
-        case url:       return QObject::tr("URL");
-        case date:      return QObject::tr("Date");
-        case misc:      return QObject::tr("Misc");
-        default:        return "";
+    case username:  return QObject::tr("Username");
+    case nick:      return QObject::tr("Nickname");
+    case password:  return QObject::tr("Password");
+    case name:      return QObject::tr("Name");
+    case first:     return QObject::tr("First Name");
+    case last:      return QObject::tr("Last Name");
+    case email:     return QObject::tr("E-mail");
+    case address:   return QObject::tr("Address");
+    case city:      return QObject::tr("City");
+    case state:     return QObject::tr("State");
+    case zip:       return QObject::tr("Zipcode");
+    case phone:     return QObject::tr("Phone");
+    case url:       return QObject::tr("URL");
+    case date:      return QObject::tr("Date");
+    case misc:      return QObject::tr("Misc");
+    default:        return "";
     };
 }
 
@@ -3271,22 +3434,22 @@ int FormField::tagNameToType(const QString &in) const
 QString FormField::typeToTagName(int type) const
 {
     switch(type) {
-        case username:  return "username";
-        case nick:      return "nick";
-        case password:  return "password";
-        case name:      return "name";
-        case first:     return "first";
-        case last:      return "last";
-        case email:     return "email";
-        case address:   return "address";
-        case city:      return "city";
-        case state:     return "state";
-        case zip:       return "zipcode";
-        case phone:     return "phone";
-        case url:       return "url";
-        case date:      return "date";
-        case misc:      return "misc";
-        default:        return "";
+    case username:  return "username";
+    case nick:      return "nick";
+    case password:  return "password";
+    case name:      return "name";
+    case first:     return "first";
+    case last:      return "last";
+    case email:     return "email";
+    case address:   return "address";
+    case city:      return "city";
+    case state:     return "state";
+    case zip:       return "zipcode";
+    case phone:     return "phone";
+    case url:       return "url";
+    case date:      return "date";
+    case misc:      return "misc";
+    default:        return "";
     };
 }
 
@@ -3294,8 +3457,7 @@ QString FormField::typeToTagName(int type) const
 //---------------------------------------------------------------------------
 // Form
 //---------------------------------------------------------------------------
-Form::Form(const Jid &j)
-:QList<FormField>()
+Form::Form(const Jid &j) : QList<FormField>()
 {
     setJid(j);
 }
