@@ -32,6 +32,7 @@ class QString;
 class QDomElement;
 class QDomDocument;
 class ByteStream;
+class QNetworkAccessManager;
 namespace XMPP {
     class ClientStream;
     class Features;
@@ -51,6 +52,12 @@ namespace XMPP {
     class Task;
     class CapsManager;
     class EncryptionHandler;
+    class ServerInfoManager;
+    class HttpFileUploadManager;
+
+    namespace Jingle {
+        class Manager;
+    }
 }
 
 namespace XMPP
@@ -126,6 +133,9 @@ namespace XMPP
         BoBManager *bobManager() const;
         JidLinkManager *jidLinkManager() const;
         CapsManager *capsManager() const;
+        ServerInfoManager *serverInfoManager() const;
+        HttpFileUploadManager *httpFileUploadManager() const;
+        Jingle::Manager* jingleManager() const;
 
         void setFileTransferEnabled(bool b);
         FileTransferManager *fileTransferManager() const;
