@@ -115,7 +115,7 @@ namespace XMPP
 
         void setPriority(int);
         void setType(Type);
-        void setType(QString);
+        void setType(const QString &);
         void setShow(const QString &);
         void setStatus(const QString &);
         void setTimeStamp(const QDateTime &);
@@ -135,7 +135,7 @@ namespace XMPP
         void setXSigned(const QString &);
         void setSongTitle(const QString &);
 
-        // JEP-153: VCard-based Avatars
+        // XEP-153: VCard-based Avatars
         const QString& photoHash() const;
         void setPhotoHash(const QString&);
         bool hasPhotoHash() const;
