@@ -36,12 +36,9 @@ using namespace XMLHelper;
 //----------------------------------------------------------------------------
 // VCard
 //----------------------------------------------------------------------------
-QString image2type(const QByteArray &ba)
+QString openedImage2type(QIODevice *dev)
 {
-    QBuffer buf;
-    buf.setData(ba);
-    buf.open(QIODevice::ReadOnly);
-    QString format = QImageReader::imageFormat( &buf ).toUpper();
+    QString format = QImageReader::imageFormat( dev ).toUpper();
 
     // TODO: add more formats: PBM PGM PPM XBM XPM
     if ( format == QLatin1String("PNG") || format == QLatin1String("PSIPNG") ) // PsiPNG in normal case
@@ -67,6 +64,14 @@ QString image2type(const QByteArray &ba)
     return QLatin1String("image/unknown");
 }
 
+QString image2type(const QByteArray &ba)
+{
+    QBuffer buf;
+    buf.setData(ba);
+    buf.open(QIODevice::ReadOnly);
+    return openedImage2type(&buf);
+}
+
 namespace XMPP {
 
 // Long lines of encoded binary data SHOULD BE folded to 75 characters using the folding method defined in [MIME-DIR].
