@@ -46,25 +46,25 @@ AboutDlg::AboutDlg(QWidget* parent)
     // fill in Authors tab...
     QString authors;
     authors += details(QString::fromUtf8("Justin Karneges"),
-               "justin@affinix.com", "", "",
+               "justin@karneges.com", "", "",
                tr("Original Author"));
     authors += details(QString::fromUtf8("Sergey Ilinykh"),
                "rion4ik@gmail.com", "", "",
                tr("Lead Developer and Current Maintainer"));
     authors += details(QString::fromUtf8("Kevin Smith"),
-               "kismith@psi-im.org", "", "",
+               "", "", "",
                tr("Past Lead Developer and Maintainer"));
     authors += details(QString::fromUtf8("Remko Tronçon"),
                "", "", "http://el-tramo.be",
                tr("Past Lead Developer"));
     authors += details(QString::fromUtf8("Michail Pishchagin"),
-               "mblsha@psi-im.org", "", "",
+               "", "", "",
                tr("Lead Widget Developer"));
     authors += details(QString::fromUtf8("Maciej Niedzielski"),
-               "machekku@psi-im.org", "", "",
+               "", "", "",
                tr("Developer"));
     authors += details(QString::fromUtf8("Martin Hostettler"),
-               "martin@psi-im.org", "", "",
+               "", "", "",
                tr("Developer"));
     authors += details(QString::fromUtf8("Evgeny Khryukin"),
                "wadealer@gmail.com", "", "",
