@@ -30,7 +30,8 @@ AccountAddDlg::AccountAddDlg(PsiCon *_psi, QWidget *parent)
 {
     setupUi(this);
     setModal(false);
-    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);
+    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint |
+                   Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint | Qt::WindowContextHelpButtonHint);
     psi = _psi;
     psi->dialogRegister(this);
 
