@@ -72,7 +72,8 @@ void AccountModifyDlg::init()
 #ifndef Q_OS_MAC
     setWindowIcon(IconsetFactory::icon("psi/account").icon());
 #endif
-    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint | Qt::WindowCloseButtonHint | Qt::CustomizeWindowHint);
+    setWindowFlags(Qt::Dialog | Qt::WindowTitleHint | Qt::WindowMinimizeButtonHint | Qt::WindowCloseButtonHint |
+                   Qt::CustomizeWindowHint | Qt::WindowContextHelpButtonHint);
 
     le_pass->setEnabled(true);
     le_host->setEnabled(false);
@@ -625,9 +626,7 @@ void AccountModifyDlg::save()
             messageBox.exec();
             Q_UNUSED(cancel);
             if (messageBox.clickedButton() == reconnect) {
-                XMPP::Status status = pa->status();
-                pa->setStatus(XMPP::Status::Offline);
-                pa->setStatus(status);
+                pa->reconnectOnce();
             }
         }
         pa->reconfigureFTManager();
