@@ -757,7 +757,7 @@ QPixmap AvatarFactory::getMucAvatar(const Jid& _jid)
     }
 
     // for mucs icons.avatar is always made of vcard and anything else is not supported. at least for now.
-    QImage img(std::move(QImage::fromData(data)));
+    QImage img(QImage::fromData(data));
 
     if (img.isNull()) {
         return QPixmap();
@@ -937,13 +937,18 @@ void AvatarFactory::vcardUpdated(const Jid &j, bool isMuc)
 {
     QByteArray ba;
     QString fullJid;
+    XMPP::VCard vcard;
     if (isMuc) {
-        ba = VCardFactory::instance()->mucVcard(j).photo();
+        vcard = VCardFactory::instance()->mucVcard(j);
         fullJid = j.full();
     } else {
-        ba = VCardFactory::instance()->vcard(j).photo();
+        vcard = VCardFactory::instance()->vcard(j);
         fullJid = j.bare();
     }
+    if (!vcard) {
+        return; // wtf??
+    }
+    ba = vcard.photo();
     if (!ba.isEmpty()) {
         if (AvatarCache::instance()->setIcon(AvatarCache::VCardType, fullJid, ba) == AvatarCache::UserUpdateRequired) {
             d->iconset_.removeIcon(QString(QLatin1String("avatars/%1")).arg(fullJid));
