@@ -25,21 +25,19 @@
 #include "textutil.h"
 
 #include <QWidget>
-#if QT_VERSION >= QT_VERSION_CHECK(5,0,0)
 #include <QJsonObject>
 #include <QMetaObject>
 #include <QMetaProperty>
 #include <QJsonDocument>
-#endif
 #ifdef WEBENGINE
-#if QT_VERSION >= QT_VERSION_CHECK(5,7,0)
-#include <QWebEngineContextMenuData>
-#endif
-#include <QWebEngineSettings>
+# if QT_VERSION >= QT_VERSION_CHECK(5,7,0)
+#  include <QWebEngineContextMenuData>
+# endif
+# include <QWebEngineSettings>
 #else
-#include <QWebPage>
-#include <QWebFrame>
-#include <QNetworkRequest>
+# include <QWebPage>
+# include <QWebFrame>
+# include <QNetworkRequest>
 #endif
 #include <QFile>
 #include <QFileInfo>
@@ -49,6 +47,7 @@
 #include <QApplication>
 #include <QMetaProperty>
 #include <QNetworkReply>
+#include <QAction>
 
 
 #include "webview.h"
@@ -65,6 +64,9 @@
 #include "desktoputil.h"
 #include "psicon.h"
 #include "xmpp_tasks.h"
+#ifdef PSI_PLUGINS
+# include "pluginmanager.h"
+#endif
 
 
 class ChatViewThemeSessionBridge;
@@ -72,28 +74,28 @@ class ChatViewJSObject;
 class ChatViewPrivate
 {
 public:
-    ChatViewPrivate() {}
+    ChatViewPrivate() = default;
 
     Theme theme;
 
-    WebView *webView;
-    ChatViewJSObject *jsObject;
+    WebView *webView = nullptr;
+    ChatViewJSObject *jsObject = nullptr;
     QList<QVariantMap> jsBuffer_;
     bool sessionReady_ = false;
-    QPointer<QWidget> dialog_ = 0;
+    QPointer<QWidget> dialog_;
     bool isMuc_ = false;
     bool isMucPrivate_ = false;
     bool isEncryptionEnabled_ = false;
     Jid jid_;
     QString name_;
-    PsiAccount *account_;
+    PsiAccount *account_ = nullptr;
     AvatarFactory::UserHashes remoteIcons;
     AvatarFactory::UserHashes localIcons;
 
     inline ChatViewThemeProvider* themeProvider() const
     {
-        return (ChatViewThemeProvider *)PsiThemeManager::instance()->
-                            provider(isMuc_?"groupchatview":"chatview");
+        return static_cast<ChatViewThemeProvider *>(PsiThemeManager::instance()->
+                            provider(isMuc_?"groupchatview":"chatview"));
     }
 
     static QString closeIconTags(const QString &richText)
@@ -279,13 +281,14 @@ private slots:
         for (auto &p : reply->rawHeaderPairs()) {
             QString key(QString(p.first).toLower());
             QString value;
+#if QT_VERSION < QT_VERSION_CHECK(5,9,3)
             if (key == QLatin1String("content-type")) {
                 // workaround for qt bug #61300 which put headers from origial request and redirect request in one hash
                 // other headers most likely are invalid too, but this one is important for us.
                 value = QString::fromLatin1(p.second).section(',', -1).trimmed();
-            } else {
+            } else
+#endif
                 value = QString::fromLatin1(p.second);
-            }
             headers.insert(key, value);
         }
         msg.insert("value", headers);
@@ -363,6 +366,27 @@ protected:
 
 #endif
 
+//----------------------------------------------------------------------------
+// ChatWebView
+//----------------------------------------------------------------------------
+class ChatWebView: public WebView
+{
+    Q_OBJECT
+
+public:
+    ChatWebView(QWidget* parent) :
+        WebView(parent)
+    {
+        auto act = new QAction(tr("Quote"), this);
+        act->setShortcut(QKeySequence(tr("Ctrl+S")));
+        addContextMenuAction(act);
+        connect(act, &QAction::triggered, this, [this](bool){ emit quote(selectedText()); });
+    }
+
+signals:
+    void quote(const QString &text);
+};
+
 //----------------------------------------------------------------------------
 // ChatView
 //----------------------------------------------------------------------------
@@ -371,7 +395,7 @@ ChatView::ChatView(QWidget *parent) :
     d(new ChatViewPrivate)
 {
     d->jsObject = new ChatViewJSObject(this); /* It's a session bridge between html and c++ part */
-    d->webView = new WebView(this);
+    d->webView = new ChatWebView(this);
     d->webView->setFocusPolicy(Qt::NoFocus);
 #ifdef WEBENGINE
     d->webView->setPage(new ChatViewPage(d->webView));
@@ -391,6 +415,19 @@ ChatView::ChatView(QWidget *parent) :
     psiOptionChanged("options.ui.automatically-copy-selected-text"); // init autocopy connection
 #endif
     connect(d->jsObject, SIGNAL(inited()), SLOT(sessionInited()));
+
+#ifdef PSI_PLUGINS
+    QVariantMap m;
+    m["type"] = "receivehooks";
+    m["hooks"] = PluginManager::instance()->messageViewJSFilters();
+    sendJsObject(m);
+    connect(PluginManager::instance(), &PluginManager::jsFiltersUpdated, this, [this](){
+        QVariantMap m;
+        m["type"] = "receivehooks";
+        m["hooks"] = PluginManager::instance()->messageViewJSFilters();
+        sendJsObject(m);
+    });
+#endif
 }
 
 ChatView::~ChatView()
@@ -400,7 +437,7 @@ ChatView::~ChatView()
     // QTBUG-48014 and bunch of others (deletes QWidget twice).
     // The bug was last time reproduced with Qt-5.9. algo is pretty simple:
     // Connect to any conference and quit Psi.
-    d->webView->setParent(0);
+    d->webView->setParent(nullptr);
     d->webView->deleteLater();
 #endif
 }
@@ -595,6 +632,14 @@ void ChatView::dispatchMessage(const MessageView &mv)
     sendJsObject(vm);
 }
 
+void ChatView::sendJsCode(const QString &js)
+{
+    QVariantMap m;
+    m["type"] = "js";
+    m["js"] = js;
+    sendJsObject(m);
+}
+
 void ChatView::scrollUp()
 {
     emit d->jsObject->scrollRequested(-50);
