@@ -353,7 +353,7 @@ void DiscoListItem::copyItem(const DiscoItem &it)
 
     if ( di.jid().bare().left(4) == "jud." || di.jid().bare().left(6) == "users." ) {
         // nasty hack for the nasty (and outdated) JUD service :-/
-        if ( !di.features().canSearch() ) {
+        if ( !di.features().hasSearch() ) {
             QStringList features = di.features().list();
             features << "jabber:iq:search";
             di.setFeatures( features );
@@ -491,7 +491,7 @@ void DiscoListItem::updateItems(bool parentAutoItems, bool more)
 
 void DiscoListItem::discoItemsFinished()
 {
-    JT_DiscoItems *jt = (JT_DiscoItems *)sender();
+    JT_DiscoItems *jt = static_cast<JT_DiscoItems *>(sender());
 
     if ( jt->success() ) {
         jt->extractSubsetInfo(subsets);
@@ -594,7 +594,6 @@ void DiscoListItem::autoItemsChildren() const
 void DiscoListItem::updateInfo()
 {
     JT_DiscoInfo *jt = new JT_DiscoInfo(d->pa->client()->rootTask());
-    jt->setAllowCache(false); // Workaround for a bug https://github.com/hanzz/spectrum2/issues/205 (invalid caps from transport)
     connect(jt, SIGNAL(finished()), SLOT(discoInfoFinished()));
     jt->get(di.jid(), di.node());
     jt->go(true);
@@ -603,7 +602,7 @@ void DiscoListItem::updateInfo()
 
 void DiscoListItem::discoInfoFinished()
 {
-    JT_DiscoInfo *jt = (JT_DiscoInfo *)sender();
+    JT_DiscoInfo *jt = static_cast<JT_DiscoInfo *>(sender());
 
     if ( jt->success() ) {
         updateInfo( jt->item() );
@@ -1192,19 +1191,19 @@ void DiscoDlg::Private::enableButtons(const DiscoItem &it)
 
     // custom actions
     Features f = it.features();
-    actRegister->setEnabled( f.canRegister() );
-    actUnregister->setEnabled( f.canRegister() );
-    actSearch->setEnabled( f.canSearch() );
-    actJoin->setEnabled( f.canGroupchat() );
+    actRegister->setEnabled( f.hasRegister() );
+    actUnregister->setEnabled( f.hasRegister() );
+    actSearch->setEnabled( f.hasSearch() );
+    actJoin->setEnabled( f.hasGroupchat() );
     actAdd->setEnabled( itemSelected );
-    actVCard->setEnabled( f.haveVCard() );
-    actAHCommand->setEnabled( f.canCommand() );
+    actVCard->setEnabled( f.hasVCard() );
+    actAHCommand->setEnabled( f.hasCommand() );
     actQueryVersion->setEnabled( f.hasVersion() );
 }
 
 void DiscoDlg::Private::itemSelected (QTreeWidgetItem *item)
 {
-    DiscoBaseItem *it = (DiscoBaseItem *)item;
+    DiscoBaseItem *it = static_cast<DiscoBaseItem *>(item);
     if ( !it ) {
         disableButtons();
         return;
@@ -1218,14 +1217,14 @@ void DiscoDlg::Private::itemSelected (QTreeWidgetItem *item)
 
 void DiscoDlg::Private::itemExpanded (QTreeWidgetItem *item)
 {
-    DiscoListItem *it = (DiscoListItem *)item;
+    DiscoListItem *it = static_cast<DiscoListItem *>(item);
     if (it)
         it->setExpanded(true);
 }
 
 void DiscoDlg::Private::itemClicked(QTreeWidgetItem *item)
 {
-    DiscoBaseItem *it = (DiscoBaseItem *)item;
+    DiscoBaseItem *it = static_cast<DiscoBaseItem *>(item);
     if (it)
         it->itemClicked();
 }
@@ -1244,7 +1243,7 @@ void DiscoDlg::Private::itemDoubleclicked (QTreeWidgetItem *item)
     long id = 0;
 
     // trigger default action
-    if (f.canCommand() ) {
+    if (f.hasCommand() ) {
         id = Features::FID_AHCommand;
     }
     if (!d.identities().isEmpty()) {
@@ -1252,13 +1251,13 @@ void DiscoDlg::Private::itemDoubleclicked (QTreeWidgetItem *item)
         DiscoItem::Identity ident = d.identities().first();
         bool searchFirst = ident.category == "service" && ident.type == "jud";
 
-        if ( searchFirst && f.canSearch() ) {
+        if ( searchFirst && f.hasSearch() ) {
             id = Features::FID_Search;
         }
-        else if ( ident.category == "conference" &&  f.canGroupchat() ) {
+        else if ( ident.category == "conference" &&  f.hasGroupchat() ) {
             id = Features::FID_Groupchat;
         }
-        else if ( f.canRegister() ) {
+        else if ( f.hasRegister() ) {
                 id = Features::FID_Register;
         }
     }
@@ -1279,7 +1278,7 @@ bool DiscoDlg::Private::eventFilter (QObject *object, QEvent *event)
 {
     if ( object == dlg->lv_disco ) {
         if ( event->type() == QEvent::ContextMenu ) {
-            QContextMenuEvent *e = (QContextMenuEvent *)event;
+            QContextMenuEvent *e = static_cast<QContextMenuEvent *>(event);
 
             QTreeWidgetItem *twi = dlg->lv_disco->currentItem();
             if (!twi || twi->type() == MoreItemsType)
