@@ -1119,9 +1119,13 @@ public:
         rate = FileTransDlg::tr("N/A");
         sent = 0;
         progress = 0;
+        bps = 0;
+        timeRemaining = 0;
+        id = 0;
         dist = -1;
+        height = 5;
         margin = 4;
-        cm = 0;
+        cm = nullptr;
     }
 
     void niceUnit(qlonglong n, qlonglong *div, QString *unit)
@@ -1596,7 +1600,10 @@ public:
 
     TransferMapping()
     {
-        h = 0;
+        h = nullptr;
+        id = 0;
+        p = 0;
+        sent = 0;
         at = 0;
     }
 
@@ -1626,10 +1633,11 @@ public:
     QList<TransferMapping*> transferList;
     QTimer t;
 
-    Private(FileTransDlg *_parent)
-    {
-        parent = _parent;
-    }
+    Private(FileTransDlg *_parent) :
+        parent(_parent),
+        psi(nullptr),
+        lv(nullptr)
+    { }
 
     ~Private()
     {
@@ -1919,7 +1927,7 @@ void FileTransDlg::clearFinished()
 
 void FileTransDlg::ft_progress(int p, qlonglong sent)
 {
-    TransferMapping *i = d->findMapping((FileTransferHandler *)sender());
+    TransferMapping *i = d->findMapping(static_cast<FileTransferHandler *>(sender()));
     i->p = p;
     i->sent = sent;
     if(p == i->h->totalSteps())
@@ -1930,7 +1938,7 @@ void FileTransDlg::ft_progress(int p, qlonglong sent)
 
 void FileTransDlg::ft_error(int x, int, const QString &s)
 {
-    TransferMapping *i = d->findMapping((FileTransferHandler *)sender());
+    TransferMapping *i = d->findMapping(static_cast<FileTransferHandler *>(sender()));
     int id = i->id;
     d->transferList.removeAll(i);
     delete i;
