@@ -91,11 +91,11 @@
 #include "pluginmanager.h"
 #endif
 #include "psirichtext.h"
-#include "psiwindowheader.h"
 #include "mcmdsimplesite.h"
 #include "tabcompletion.h"
 #include "vcardfactory.h"
 #include "languagemanager.h"
+#include "filesharedlg.h"
 #include "tabdlg.h"
 
 #ifdef Q_OS_WIN
@@ -259,16 +259,13 @@ public:
 
     int logSize;
     int rosterSize;
+public:
+    bool trackBar;
+    bool tabmode;
 
     int logHeight;
     int chateditHeight;
 
-public:
-    bool trackBar;
-
-    bool tabmode;
-    PsiWindowHeader *winHeader_;
-
 public:
     ChatEdit* mle() const { return dlg->ui_.mle->chatEdit(); }
     ChatView* te_log() const { return dlg->ui_.log; }
@@ -324,7 +321,7 @@ public slots:
 
     void lastactivity_finished()
     {
-        LastActivityTask *idle = (LastActivityTask *)sender();
+        LastActivityTask *idle = static_cast<LastActivityTask *>(sender());
 
         if (!idle->success()) {
             dlg->appendSysMsg(QString("Can't determine last activity time for %1.").arg(idle->jid().resource()), false);
@@ -569,7 +566,7 @@ public:
             return true;
 
         if ( obj == mle() && ev->type() == QEvent::KeyPress ) {
-            QKeyEvent *e = (QKeyEvent *)ev;
+            QKeyEvent *e = static_cast<QKeyEvent *>(ev);
 
             if ( e->key() == Qt::Key_Tab ) {
                 tabCompletion.tryComplete();
@@ -855,13 +852,6 @@ GCMainDlg::GCMainDlg(PsiAccount *pa, const Jid &j, TabManager *tabManager)
 
     ui_.setupUi(this);
     d->tabmode = PsiOptions::instance()->getOption("options.ui.tabs.use-tabs").toBool();
-    setWindowBorder(PsiOptions::instance()->getOption("options.ui.decorate-windows").toBool());
-    if (!d->tabmode && !isBorder()) {
-        d->winHeader_ = new PsiWindowHeader(this);
-        ui_.vboxLayout1->insertWidget(0, d->winHeader_);
-    }
-    setMargins();
-
     ui_.lb_ident->setAccount(account());
     ui_.lb_ident->setShowJid(false);
     ui_.log->setSessionData(true, false, jid(), jid().full()); //FIXME change conference name
@@ -2341,25 +2331,6 @@ void GCMainDlg::setLooks()
     setMucSelfAvatar();
 }
 
-void GCMainDlg::setMargins()
-{
-    ui_.vboxLayout->setContentsMargins(0,0,0,0);
-    ui_.vboxLayout2->setContentsMargins(4,0,4,4);
-    if (!d->tabmode) {
-        ui_.hboxLayout->setContentsMargins(4,0,4,0);
-        if (!isBorder()) {
-            ui_.vboxLayout1->setContentsMargins(0,0,0,0);
-        }
-        else {
-            ui_.vboxLayout1->setContentsMargins(0,4,0,0);
-        }
-    }
-    else {
-        ui_.vboxLayout1->setContentsMargins(4,4,4,0);
-        ui_.hboxLayout->setContentsMargins(2,0,4,0);
-    }
-}
-
 void GCMainDlg::setToolbuttons()
 {
     ui_.toolbar->clear();
@@ -2562,6 +2533,20 @@ void GCMainDlg::chatEditCreated()
     ui_.mle->chatEdit()->setDialog(this);
 
     ui_.mle->chatEdit()->installEventFilter(d);
+    connect(ui_.mle->chatEdit(), &ChatEdit::imagePasted, this, [this](const QImage &img) {
+        auto dlg = new FileShareDlg(this);
+        dlg->setImage(img);
+        connect(dlg, &FileShareDlg::accepted, this, [this, img, dlg](){
+            account()->shareImage(jid(), img, dlg->description(), [this](const QString &getUrl) {
+                qDebug("successfully shared: %s", qPrintable(getUrl));
+                Message m(jid());
+                m.setType("groupchat");
+                m.setBody(getUrl);
+                aSend(m);
+            });
+        });
+        dlg->exec();
+    });
 }
 
 TabbableWidget::State GCMainDlg::state() const
