@@ -675,7 +675,7 @@ HistoryDlg::HistoryDlg(const Jid &jid, PsiAccount *pa)
     setLooks(ui_.msgLog);
     ui_.contactList->setFont(fontForOption("options.ui.look.font.contactlist"));
 
-    ui_.calendar->setFirstDayOfWeek(firstDayOfWeekFromLocale());
+    ui_.calendar->setFirstDayOfWeek(QLocale().firstDayOfWeek());
 
     connect(ui_.searchField, SIGNAL(returnPressed()), SLOT(findMessages()));
     connect(ui_.searchField, SIGNAL(textChanged(const QString)), SLOT(highlightBlocks()));
@@ -941,7 +941,9 @@ void HistoryDlg::highlightBlocks()
     const QString text = ui_.searchField->text();
     QTextCursor cur = ui_.msgLog->textCursor();
     QTextCursor old = cur;
-    int sc_pos = ui_.msgLog->verticalScrollBar()->value();
+    int sc_pos = 0;
+    if (ui_.msgLog->verticalScrollBar())
+        sc_pos = ui_.msgLog->verticalScrollBar()->value();
     cur.clearSelection();
     cur.movePosition(QTextCursor::Start);
     ui_.msgLog->setTextCursor(cur);
@@ -962,7 +964,8 @@ void HistoryDlg::highlightBlocks()
 
     ui_.msgLog->setExtraSelections(extras);
     ui_.msgLog->setTextCursor(old);
-    ui_.msgLog->verticalScrollBar()->setValue(sc_pos);
+    if (ui_.msgLog->verticalScrollBar())
+        ui_.msgLog->verticalScrollBar()->setValue(sc_pos);
 }
 
 void HistoryDlg::findMessages()
