@@ -25,11 +25,7 @@
 #include <QStyleOption>
 
 
-#ifdef HAVE_QT5
 typedef QStyleOptionViewItem HoverableStyleOptionViewItemBaseClass;
-#else
-typedef QStyleOptionViewItemV4 HoverableStyleOptionViewItemBaseClass;
-#endif
 
 class HoverableStyleOptionViewItem : public HoverableStyleOptionViewItemBaseClass
 {
