@@ -40,6 +40,7 @@
 #include "userlist.h"
 #include "xmpp_vcard.h"
 #include "xmpp_tasks.h"
+#include "xmpp_serverinfomanager.h"
 #include "psiaccount.h"
 #include "busywidget.h"
 #include "iconset.h"
@@ -59,17 +60,17 @@ using namespace XMPP;
 class InfoWidget::Private
 {
 public:
-    Private() {}
+    Private() = default;
 
-    int type;
+    int type = 0;
     Jid jid;
     VCard vcard;
-    PsiAccount *pa;
-    bool busy;
-    bool te_edited;
-    int actionType;
-    JT_VCard *jt;
-    bool cacheVCard;
+    PsiAccount *pa = nullptr;
+    bool busy = false;
+    bool te_edited = false;
+    int actionType = 0;
+    JT_VCard *jt = nullptr;
+    bool cacheVCard = false;
     QByteArray photo;
     QDate bday;
     QString dateTextFormat;
@@ -79,10 +80,10 @@ public:
     QPointer<QPushButton> noBdayButton;
     QPointer<QFrame> bdayPopup;
     QPointer<QCalendarWidget> calendar;
-    QLineEdit *le_givenname;
-    QLineEdit *le_middlename;
-    QLineEdit *le_familyname;
-    QAction *homepageAction;
+    QLineEdit *le_givenname = nullptr;
+    QLineEdit *le_middlename = nullptr;
+    QLineEdit *le_familyname = nullptr;
+    QAction *homepageAction = nullptr;
 
     // Fake UserListItem for groupchat contacts.
     // One day this dialog should be rewritten not to talk directly to psiaccount,
@@ -174,7 +175,7 @@ InfoWidget::InfoWidget(int type, const Jid &j, const VCard &vcard, PsiAccount *p
         QVBoxLayout* vbox = new QVBoxLayout(d->bdayPopup);
 
         d->calendar = new QCalendarWidget(d->bdayPopup);
-        d->calendar->setFirstDayOfWeek(firstDayOfWeekFromLocale());
+        d->calendar->setFirstDayOfWeek(QLocale().firstDayOfWeek());
         d->calendar->setVerticalHeaderFormat(QCalendarWidget::NoVerticalHeader);
         vbox->addWidget(d->calendar);
 
@@ -217,7 +218,7 @@ InfoWidget::InfoWidget(int type, const Jid &j, const VCard &vcard, PsiAccount *p
         ur.setStatus(pa->gcContactStatus(j));
         d->userListItem->userResourceList().append(ur);
     } else {
-        d->userListItem = 0;
+        d->userListItem = nullptr;
     }
 
     // Add a status tab
@@ -745,6 +746,29 @@ void InfoWidget::updateStatus()
     UserListItem *u = d->find(d->jid);
     if(u) {
         PsiRichText::setText(ui_.te_status->document(), u->makeDesc());
+    } else if (d->jid.node().isEmpty() && d->jid.domain() == d->pa->jid().domain()) { // requesting info for our server.
+        // let's add some more stuff..
+        static const QMap<QString,QString> transMap{
+            {"abuse-addresses", tr("Abuse")},
+            {"admin-addresses", tr("Administrators")},
+            {"feedback-addresses", tr("Feedback")},
+            {"sales-addresses", tr("Sales")},
+            {"security-addresses", tr("Security")},
+            {"support-addresses", tr("Support")}
+        };
+        QString info;
+        QMapIterator<QString,QStringList> it(d->pa->serverInfoManager()->extraServerInfo());
+        while (it.hasNext()) {
+            auto l = it.next();
+            auto at = transMap.value(l.key());
+            if (!at.isEmpty()) {
+                info += QLatin1String("<b>") + at + QLatin1String(":</b><br>");
+                for (const auto &a: l.value()) {
+                    info += QLatin1String("  ") + a  + QLatin1String("<br>");
+                }
+            }
+        }
+        PsiRichText::setText(ui_.te_status->document(), info);
     }
     else {
         ui_.te_status->clear();
@@ -789,7 +813,7 @@ void InfoWidget::requestResourceInfo(const Jid& j)
 
 void InfoWidget::clientVersionFinished()
 {
-    JT_ClientVersion *j = (JT_ClientVersion *)sender();
+    JT_ClientVersion *j = static_cast<JT_ClientVersion *>(sender());
     if(j->success()) {
         foreach(UserListItem* u, d->findRelevant(j->jid())) {
             UserResourceList::Iterator rit = u->userResourceList().find(j->jid().resource());
@@ -807,7 +831,7 @@ void InfoWidget::clientVersionFinished()
 
 void InfoWidget::entityTimeFinished()
 {
-    JT_EntityTime *j = (JT_EntityTime *)sender();
+    JT_EntityTime *j = static_cast<JT_EntityTime *>(sender());
     if(j->success()) {
         foreach(UserListItem* u, d->findRelevant(j->jid())) {
             UserResourceList::Iterator rit = u->userResourceList().find(j->jid().resource());
@@ -831,7 +855,7 @@ void InfoWidget::requestLastActivity()
 
 void InfoWidget::requestLastActivityFinished()
 {
-    LastActivityTask *j = (LastActivityTask *)sender();
+    LastActivityTask *j = static_cast<LastActivityTask *>(sender());
     if(j->success()) {
         foreach(UserListItem* u, d->findRelevant(d->jid)) {
             u->setLastUnavailableStatus(makeStatus(STATUS_OFFLINE,j->status()));
