@@ -21,18 +21,7 @@
 #include "jsutil.h"
 #include <QStringList>
 #include <QDateTime>
-
-QString JSUtil::map2json(const QVariantMap &map)
-{
-    QStringList ret;
-    QMapIterator<QString, QVariant> i(map);
-    while (i.hasNext()) {
-        i.next();
-        ret.append(QString("\"%1\":").arg(escapeStringCopy(i.key())) +
-                   variant2js(i.value()));
-    }
-    return QString("{%1}").arg(ret.join(","));
-}
+#include <QJsonDocument>
 
 QString JSUtil::variant2js(const QVariant &value)
 {
@@ -72,7 +61,7 @@ QString JSUtil::variant2js(const QVariant &value)
             strVal = QString("new Date(%1)").arg(value.toDate().toString("yyyy,M-1,d"));
             break;
         case QVariant::Map:
-            strVal = map2json(value.toMap());
+            strVal = QString::fromUtf8(QJsonDocument::fromVariant(value).toJson(QJsonDocument::Compact));
             break;
         default:
             strVal = value.toString();
