@@ -57,7 +57,7 @@ public:
         connect(te_->document(), SIGNAL(contentsChange(int,int,int)), SLOT(textChanged(int,int,int)));
     }
 
-    virtual ~CapitalLettersController() {};
+    virtual ~CapitalLettersController() {}
 
     void setAutoCapitalizeEnabled(bool enabled)
     {
@@ -165,9 +165,6 @@ private:
 //----------------------------------------------------------------------------
 ChatEdit::ChatEdit(QWidget *parent)
     : QTextEdit(parent)
-    , dialog_(0)
-    , check_spelling_(false)
-    , spellhighlighter_(0)
     , palOriginal(palette())
     , palCorrection(palOriginal)
 {
@@ -195,7 +192,6 @@ ChatEdit::ChatEdit(QWidget *parent)
 ChatEdit::~ChatEdit()
 {
     clearMessageHistory();
-    delete spellhighlighter_;
     delete controller_;
     delete capitalizer_;
 }
@@ -277,11 +273,10 @@ void ChatEdit::setCheckSpelling(bool b)
     check_spelling_ = b;
     if (check_spelling_) {
         if (!spellhighlighter_)
-            spellhighlighter_ = new SpellHighlighter(document());
+            spellhighlighter_.reset(new SpellHighlighter(document()));
     }
     else {
-        delete spellhighlighter_;
-        spellhighlighter_ = 0;
+        spellhighlighter_.reset();
     }
 }
 
@@ -512,6 +507,17 @@ void ChatEdit::setEditText(const QString& text)
     moveCursor(QTextCursor::End);
 }
 
+void ChatEdit::insertFromMimeData(const QMimeData *source)
+{
+    if (source->hasImage()) {
+        auto img = qvariant_cast<QImage>(source->imageData());
+        if (!img.isNull()) {
+            emit imagePasted(img);
+        }
+    }
+    QTextEdit::insertFromMimeData(source);
+}
+
 void ChatEdit::updateBackground() {
     setPalette(correction ? palCorrection : palOriginal);
 }
