@@ -24,8 +24,9 @@
 #include "bytearrayreply.h"
 #include <QCoreApplication>
 
-NetworkAccessManager::NetworkAccessManager(QObject *parent) :
-    QNetworkAccessManager(parent)
+NetworkAccessManager::NetworkAccessManager(QObject *parent)
+    : QNetworkAccessManager(parent)
+    , _handlerSeed(0)
 {
 }
 
@@ -48,11 +49,7 @@ QNetworkReply *NetworkAccessManager::createRequest(Operation op, const QNetworkR
     }
 
     if (!reply) {
-#ifdef HAVE_QT5
         QString ua = req.header(QNetworkRequest::UserAgentHeader).toString();
-#else
-        QString ua = QString(req.rawHeader("User-Agent"));
-#endif
         auto handler = _sessionHandlers.value(ua);
         if (handler && handler->data(req, data, mime)) {
             reply = new ByteArrayReply(req, data, mime, this);
@@ -82,7 +79,6 @@ QString NetworkAccessManager::registerSessionHandler(const QSharedPointer<NAMDat
     _handlerSeed += 0x10;
 
     _sessionHandlers.insert(s, handler);
-
     return s;
 }
 
