@@ -84,7 +84,6 @@ public:
 OptionsTabToolbars::OptionsTabToolbars(QObject *parent)
     : OptionsTab(parent, "toolbars", "", tr("Toolbars"), tr("Configure Psi toolbars"), "psi/toolbars")
 {
-    w = 0;
     p = new Private();
     p->q = this;
 
@@ -184,7 +183,7 @@ void OptionsTabToolbars::setData(PsiCon * psi_, QWidget *parent_)
 
 /*void OptionsTabToolbars::setCurrentToolbar(PsiToolBar *t)
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
 
     if ( pb_apply->isEnabled() )
         return;
@@ -216,7 +215,7 @@ void OptionsTabToolbars::restoreOptions()
     if (!w)
         return;
 
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
 
     PsiOptions *o = PsiOptions::instance();
 
@@ -274,7 +273,7 @@ void OptionsTabToolbars::restoreOptions()
 
 void OptionsTabToolbars::toolbarAdd()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
 
     ToolbarPrefs tb;
     int j = 0;
@@ -301,7 +300,7 @@ void OptionsTabToolbars::toolbarAdd()
     tb.nl = true;
     // tb.extraOffset = 0;
 
-    tb.dirty = true;
+    //tb.dirty = true;
 
     p->toolbars << tb;
 
@@ -315,7 +314,7 @@ void OptionsTabToolbars::toolbarAdd()
 
 void OptionsTabToolbars::toolbarDelete()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     int n = d->cb_toolbars->currentIndex();
 
     noDirty = true;
@@ -364,7 +363,7 @@ void OptionsTabToolbars::toolbarSelectionChanged(int item)
     bool customizeable = true;
     bool moveable      = true;
 
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     bool enable = (item == -1) ? false : true;
     d->le_toolbarName->setEnabled(enable);
     // d->pb_toolbarPosition->setEnabled(enable && moveable);
@@ -449,7 +448,7 @@ void OptionsTabToolbars::toolbarSelectionChanged(int item)
 
 void OptionsTabToolbars::rebuildToolbarKeys()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     if (!d->cb_toolbars->count())
         return;
     int n = d->cb_toolbars->currentIndex();
@@ -468,7 +467,7 @@ void OptionsTabToolbars::rebuildToolbarKeys()
 
 void OptionsTabToolbars::updateArrows()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     bool up = false, down = false, left = false, right = false;
 
     if (d->tw_availActions->currentItem() && !d->tw_availActions->currentItem()->data(0, Qt::UserRole).toString().isEmpty())
@@ -505,7 +504,7 @@ void OptionsTabToolbars::updateArrows()
 
 void OptionsTabToolbars::toolbarNameChanged()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     if (!d->cb_toolbars->count())
         return;
 
@@ -521,7 +520,7 @@ void OptionsTabToolbars::toolbarNameChanged()
 
 void OptionsTabToolbars::toolbarActionUp()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     QListWidgetItem *item = d->lw_selectedActions->currentItem();
     if (!item)
         return;
@@ -543,7 +542,7 @@ void OptionsTabToolbars::toolbarActionUp()
 
 void OptionsTabToolbars::toolbarActionDown()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     QListWidgetItem *item = d->lw_selectedActions->currentItem();
     if (!item)
         return;
@@ -565,7 +564,7 @@ void OptionsTabToolbars::toolbarActionDown()
 
 void OptionsTabToolbars::toolbarAddAction()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     QTreeWidgetItem *item = d->tw_availActions->currentItem();
     if (!item || item->data(0, Qt::UserRole).toString().isEmpty())
         return;
@@ -577,7 +576,7 @@ void OptionsTabToolbars::toolbarAddAction()
 
 void OptionsTabToolbars::toolbarRemoveAction()
 {
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     QListWidgetItem *item = d->lw_selectedActions->currentItem();
     if (!item)
         return;
@@ -593,14 +592,14 @@ void OptionsTabToolbars::toolbarDataChanged()
     if (noDirty)
         return;
 
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     if (!d->cb_toolbars->count())
         return;
     int n = d->cb_toolbars->currentIndex();
 
     ToolbarPrefs tb = p->toolbars[n];
 
-    tb.dirty = true;
+    //tb.dirty = true;
     if (n > 1) {
         tb.name = d->le_toolbarName->text();
         tb.locked = d->ck_toolbarLocked->isChecked();
@@ -632,7 +631,7 @@ void OptionsTabToolbars::toolbarPosition()
 {
 #if 0
     LEGOPTFIXME
-    LookFeelToolbarsUI *d = (LookFeelToolbarsUI *)w;
+    LookFeelToolbarsUI *d = static_cast<LookFeelToolbarsUI *>(w);
     if (!d->cb_toolbars->count())
         return;
     int n = d->cb_toolbars->currentIndex();
