@@ -53,6 +53,8 @@
 #include "textutil.h"
 #include "chattabaccessor.h"
 #include "pluginaccessor.h"
+#include "chatview.h"
+#include "webkitaccessor.h"
 
 /**
  * \brief Constructs a host/wrapper for a plugin.
@@ -68,11 +70,11 @@
  */
 PluginHost::PluginHost(PluginManager* manager, const QString& pluginFile)
     : manager_(manager)
-    , plugin_(0)
+    , plugin_(nullptr)
     , file_(pluginFile)
     , priority_(PsiPlugin::PriorityNormal)
-    , loader_(0)
-    , iconset_(0)
+    , loader_(nullptr)
+    , iconset_(nullptr)
     , valid_(false)
     , connected_(false)
     , enabled_(false)
@@ -94,7 +96,7 @@ PluginHost::~PluginHost()
     unload();
     if (loader_) {
         delete loader_;
-        loader_ = 0;
+        loader_ = nullptr;
     }
 }
 
@@ -181,7 +183,7 @@ QStringList PluginHost::pluginFeatures() const
  */
 QWidget* PluginHost::optionsWidget() const
 {
-    QWidget* widget = 0;
+    QWidget* widget = nullptr;
     if (plugin_) {
         widget = qobject_cast<PsiPlugin*>(plugin_)->options();
     }
@@ -224,7 +226,7 @@ bool PluginHost::load()
             qDebug() << "Error loading plugin:" << loader_->errorString();
 #endif
             delete loader_;
-            loader_ = 0;
+            loader_ = nullptr;
         }
         else if (plugin) {
 #ifndef PLUGINS_NO_DEBUG
@@ -256,13 +258,13 @@ bool PluginHost::load()
                     loader_->unload();
                 }
                 delete loader_;
-                loader_ = 0;
+                loader_ = nullptr;
                 valid_ = false;
             }
         }
     }
 
-    return plugin_ != 0;
+    return plugin_ != nullptr;
 }
 
 /**
@@ -290,14 +292,14 @@ bool PluginHost::unload()
             // we can delete the loader;
             delete plugin_;
             delete loader_;
-            plugin_ = 0;
-            loader_ = 0;
+            plugin_ = nullptr;
+            loader_ = nullptr;
             delete iconset_;
-            iconset_ = 0;
+            iconset_ = nullptr;
             connected_ = false;
         }
     }
-    return plugin_ == 0;
+    return plugin_ == nullptr;
 }
 
 /**
@@ -305,7 +307,7 @@ bool PluginHost::unload()
  */
 bool PluginHost::isLoaded() const
 {
-    return plugin_ != 0;
+    return plugin_ != nullptr;
 }
 
 /**
@@ -460,6 +462,10 @@ bool PluginHost::enable()
 #endif
               pla->setPluginAccessingHost(this);
             }
+            auto wka = qobject_cast<WebkitAccessor*>(plugin_);
+            if (wka) {
+                wka->setWebkitAccessingHost(this);
+            }
 
             connected_ = true;
         }
@@ -1387,6 +1393,42 @@ QObject* PluginHost::getPlugin(const QString &name)
   return nullptr;
 }
 
+WebkitAccessingHost::RenderType PluginHost::chatLogRenderType() const
+{
+#ifdef WEBKIT
+# ifdef WEBENGINE
+    return WebkitAccessingHost::RT_WebEngine;
+# else
+    return WebkitAccessingHost::RT_WebKit;
+# endif
+#else
+    return WebkitAccessingHost::RT_TextEdit;
+#endif
+}
+
+QString PluginHost::installChatLogJSDataFilter(const QString &js, PsiPlugin::Priority priority)
+{
+    return manager_->installChatLogJSDataFilter(js, priority);
+}
+
+void PluginHost::uninstallChatLogJSDataFilter(const QString &id)
+{
+    manager_->uninstallChatLogJSDataFilter(id);
+}
+
+void PluginHost::executeChatLogJavaScript(QWidget *log, const QString &js)
+{
+#ifdef WEBKIT
+    auto cv = qobject_cast<ChatView *>(log);
+    if (!cv) {
+        cv = log->findChild<ChatView *>("log");
+    }
+    if (cv) {
+        cv->sendJsCode(js);
+    }
+#endif
+}
+
 //-- helpers --------------------------------------------------------
 
 static bool operator<(const QRegExp &a, const QRegExp &b)
