@@ -9,6 +9,7 @@
 #include <QtCrypto>
 #include <QPluginLoader>
 #include <QLabel>
+#include <QMetaObject>
 
 #include "xmpp_client.h"
 #include "xmpp_task.h"
@@ -92,7 +93,7 @@ PluginManager* PluginManager::instance()
  * Default constructor. Locates all plugins, sets watchers on those directories to
  * locate new ones and loads those enabled in the config.
  */
-PluginManager::PluginManager() : QObject(NULL), psi_(0)
+PluginManager::PluginManager() : QObject(NULL), psi_(nullptr)
 {
     updatePluginsList();
     foreach (QString path, pluginDirs()) {
@@ -100,6 +101,12 @@ PluginManager::PluginManager() : QObject(NULL), psi_(0)
         connect(dw, SIGNAL(changed()), SLOT(dirsChanged()));
         dirWatchers_.append(dw);
     }
+
+    _messageViewJSFiltersTimer = new QTimer(this);
+    _messageViewJSFiltersTimer->setSingleShot(true);
+    _messageViewJSFiltersTimer->setInterval(10); // to be able to restart in case of batch events
+    connect(_messageViewJSFiltersTimer, &QTimer::timeout, this, &PluginManager::jsFiltersUpdated);
+
     connect(PsiOptions::instance(), SIGNAL(optionChanged(const QString&)), this, SLOT(optionChanged(const QString&)));
 }
 
@@ -703,7 +710,7 @@ bool PluginManager::setTune(int account, const QString& jid, const QString& tune
 void PluginManager::initPopup(const QString& text, const QString& title, const QString& icon, int type)
 {
     const PsiIcon* ico = IconsetFactory::iconPtr(icon);
-    psi_->popupManager()->doPopup(0, Jid(), ico, title, 0, 0, text, true, (PopupManager::PopupType)type);
+    psi_->popupManager()->doPopup(nullptr, Jid(), ico, title, nullptr, nullptr, text, true, (PopupManager::PopupType)type);
 }
 
 void PluginManager::initPopupForJid(int account, const QString &jid, const QString &text, const QString &title, const QString &icon, int type)
@@ -718,7 +725,7 @@ void PluginManager::initPopupForJid(int account, const QString &jid, const QStri
         psi_->popupManager()->doPopup(pa, j, ico, title, &pix, statusIco, text, true, (PopupManager::PopupType)type);
         return;
     }
-    psi_->popupManager()->doPopup(0, Jid(), ico, title, 0, 0, text, true, (PopupManager::PopupType)type);
+    psi_->popupManager()->doPopup(nullptr, Jid(), ico, title, nullptr, nullptr, text, true, (PopupManager::PopupType)type);
 }
 
 int PluginManager::registerOption(const QString& name, int initValue, const QString& path)
@@ -959,6 +966,43 @@ void PluginManager::createNewMessageEvent(int account, QDomElement const &elemen
     }
 }
 
+QString PluginManager::installChatLogJSDataFilter(const QString &js, PsiPlugin::Priority priority)
+{
+    QString uuid = QUuid::createUuid().toString();
+    _messageViewJSFilters.insert(priority, {uuid, js});
+    _messageViewJSFiltersTimer->start();
+    return uuid;
+}
+
+void PluginManager::uninstallChatLogJSDataFilter(const QString &id)
+{
+    QMutableMapIterator<PsiPlugin::Priority,std::pair<QString,QString>> it(_messageViewJSFilters);
+
+    while (it.hasNext()) {
+        if (it.next().value().first == id) {
+            it.remove();
+            _messageViewJSFiltersTimer->start();
+            return;
+        }
+    }
+}
+
+QStringList PluginManager::messageViewJSFilters() const
+{
+    if (_messageViewJSFilters.isEmpty()) {
+        return QStringList();
+    }
+    QStringList ret;
+    ret.reserve(_messageViewJSFilters.size());
+    for (int i = PsiPlugin::PriorityHighest; i >= PsiPlugin::PriorityLowest; i--) {
+        auto values = _messageViewJSFilters.values(PsiPlugin::Priority(i));
+        for (const auto &p: values) {
+            ret.append(p.second);
+        }
+    }
+    return ret;
+}
+
 bool PluginManager::isSelf(int account, const QString& jid) const
 {
     PsiAccount *acc = accountIds_.account(account);
@@ -1121,7 +1165,7 @@ void AccountIds::removeAccount(PsiAccount *acc)
     int id = acc_keys.value(acc, -1);
     if (id != -1) {
         acc_keys.remove(acc);
-        id_keys[id] = 0;
+        id_keys[id] = nullptr;
     }
 }
 
@@ -1133,7 +1177,7 @@ void AccountIds::clear()
 
 PsiAccount *AccountIds::account(int id) const
 {
-    return id_keys.value(id, 0);
+    return id_keys.value(id, nullptr);
 }
 
 int AccountIds::id(PsiAccount *acc) const
@@ -1141,6 +1185,6 @@ int AccountIds::id(PsiAccount *acc) const
     return acc_keys.value(acc, -1);
 }
 
-PluginManager* PluginManager::instance_ = NULL;
+PluginManager* PluginManager::instance_ = nullptr;
 const QString PluginManager::loadOptionPrefix = "plugins.auto-load";
 const QString PluginManager::pluginOptionPrefix = "plugins.options";
