@@ -1,6 +1,6 @@
 /*
  * request.h - plugin
- * Copyright (C) 2011  Khryukin Evgeny
+ * Copyright (C) 2011  Evgeny Khryukin
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,17 +24,17 @@
 #include "figure.h"
 
 struct Request {
-	int account;
-	QString jid;
-	QString yourJid;
-	Figure::GameType type;
-	QString requestId;
-	QString chessId;
+    int account = 0;
+    QString jid;
+    QString yourJid;
+    Figure::GameType type = Figure::GameType::NoGame;
+    QString requestId;
+    QString chessId;
 
-	bool operator==(const Request& other)
-	{
-		return jid == other.jid && account == other.account;
-	}
+    bool operator==(const Request& other)
+    {
+        return jid == other.jid && account == other.account;
+    }
 };
 
 
