@@ -21,7 +21,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -398,7 +398,7 @@ void AuthenticationDialog::updateSMP(int progress)
         else
         {
             notify(QMessageBox::Warning,
-                   tr("An error occured during the authentication process."));
+                   tr("An error occurred during the authentication process."));
         }
 
         if (m_isSender)
