@@ -20,7 +20,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  */
 
@@ -230,7 +230,7 @@ void PsiOtrPlugin::restoreOptions()
 
 QPixmap PsiOtrPlugin::icon() const
 {
-	return QPixmap(":/otrplugin/otr_yes.png");
+    return QPixmap(":/otrplugin/otr_yes.png");
 }
 
 //-----------------------------------------------------------------------------
@@ -270,7 +270,7 @@ QString PsiOtrPlugin::pluginInfo() {
 
 //-----------------------------------------------------------------------------
 
-bool PsiOtrPlugin::processEvent(int accountIndex, QDomElement& e)
+bool PsiOtrPlugin::processEvent(int, QDomElement&)
 {
     return false;
 }
@@ -301,11 +301,7 @@ bool PsiOtrPlugin::decryptMessageElement(int accountIndex, QDomElement &messageE
         }
         else if (!plainBody.isNull())
         {
-#ifdef HAVE_QT5
             cyphertext = plainBody.firstChild().toText().nodeValue().toHtmlEscaped();
-#else
-            cyphertext = Qt::escape(plainBody.firstChild().toText().nodeValue());
-#endif
         }
         else
         {
@@ -385,7 +381,9 @@ bool PsiOtrPlugin::decryptMessageElement(int accountIndex, QDomElement &messageE
 
 //-----------------------------------------------------------------------------
 
-bool PsiOtrPlugin::processMessage(int, const QString&, const QString&,
+bool PsiOtrPlugin::processMessage(int,
+                                  const QString&,
+                                  const QString&,
                                   const QString&)
 {
     return false;
@@ -393,8 +391,10 @@ bool PsiOtrPlugin::processMessage(int, const QString&, const QString&,
 
 //-----------------------------------------------------------------------------
 
-bool PsiOtrPlugin::processOutgoingMessage(int accountIndex, const QString& contact,
-                                          QString& body, const QString& type,
+bool PsiOtrPlugin::processOutgoingMessage(int,
+                                          const QString&,
+                                          QString&,
+                                          const QString&,
                                           QString&)
 {
     return false;
@@ -422,11 +422,7 @@ bool PsiOtrPlugin::encryptMessageElement(int accountIndex, QDomElement &message)
     QString encrypted = m_otrConnection->encryptMessage(
         account,
         getCorrectJid(accountIndex, message.attribute("to")),
-#ifdef HAVE_QT5
         body.nodeValue().toHtmlEscaped());
-#else
-        Qt::escape(body.nodeValue()));
-#endif
 
     //if there has been an error, drop the message
     if (encrypted.isEmpty())
@@ -924,7 +920,3 @@ QString PsiOtrPlugin::getCorrectJid(int accountIndex, const QString& fullJid)
 } // namespace psiotr
 
 //-----------------------------------------------------------------------------
-#ifndef HAVE_QT5
-Q_EXPORT_PLUGIN2(psiOtrPlugin, psiotr::PsiOtrPlugin)
-#endif
-//-----------------------------------------------------------------------------
