@@ -28,25 +28,25 @@
 
 class Model : public QAbstractTableModel
 {
-	Q_OBJECT
+    Q_OBJECT
 
 public:
-        Model(QStringList Jids_, QVariantList selected_, QObject *parent = 0);
-	~Model() {}
+        Model(const QStringList &Jids_, QVariantList selected_, QObject *parent = nullptr);
+    ~Model() {}
         virtual Qt::ItemFlags flags ( const QModelIndex & index ) const;
         virtual QVariant headerData ( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
         virtual QVariant data ( const QModelIndex & index, int role = Qt::DisplayRole ) const;
         virtual int rowCount ( const QModelIndex & parent = QModelIndex() ) const;
         virtual int columnCount ( const QModelIndex & parent = QModelIndex() ) const;
-        virtual bool setData ( const QModelIndex & index, const QVariant & value, int role = Qt::EditRole );
+        virtual bool setData ( const QModelIndex & index, const QVariant & value, const int role = Qt::EditRole );
         QString jid(const QModelIndex & index) const;
         void reset();
         void apply();
         void addRow();
-	void deleteRow(int row);
-	int indexByJid(const QString& jid) const;
-	QVariantList enableFor() const;
-	QStringList getJids() const;
+    void deleteRow(const int row);
+    int indexByJid(const QString &jid) const;
+    QVariantList enableFor() const;
+    QStringList getJids() const;
 
 
 private:
