@@ -26,11 +26,7 @@ void Viewer::init()
 {
         setSelectionBehavior(QAbstractItemView::SelectRows);
         resizeColumnsToContents();
-#ifdef HAVE_QT5
         horizontalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
-#else
-        horizontalHeader()->setResizeMode(QHeaderView::ResizeToContents);
-#endif
         horizontalHeader()->setStretchLastSection(true);
         verticalHeader()->setDefaultAlignment( Qt::AlignHCenter );
 
@@ -39,6 +35,6 @@ void Viewer::init()
 
 void Viewer::itemClicked(QModelIndex index)
 {
-	if(index.column() == 0)
-		model()->setData(index, 3); //invert
+    if(index.column() == 0)
+        model()->setData(index, 3); //invert
 }
