@@ -12,7 +12,7 @@ public:
 
     virtual bool appendSysMsg(int account, const QString& jid, const QString& message) = 0;
 
-    virtual bool appendMsg(int account, const QString& jid, const QString& message, const QString& id) = 0;
+    virtual bool appendMsg(int account, const QString& jid, const QString& message, const QString& id, bool wasEncrypted = false) = 0;
 };
 
 Q_DECLARE_INTERFACE(PsiAccountControllingHost, "org.psi-im.PsiAccountControllingHost/0.1");
