@@ -53,6 +53,7 @@ namespace XMPP
     //class StreamError;
     class Resource;
     class Message;
+    class ServerInfoManager;
 };
 
 using namespace XMPP;
@@ -83,7 +84,6 @@ class QSSLCert;
 class QHostAddress;
 class AvatarFactory;
 class PEPManager;
-class ServerInfoManager;
 class TabManager;
 #ifdef GOOGLE_FT
 class GoogleFileTransfer;
@@ -224,6 +224,9 @@ public:
     QStringList localMucBookmarks() const;
     QStringList ignoreMucBookmarks() const;
 
+    void shareImage(const Jid &target, const QImage &image, const QString &description,
+                    std::function<void(const QString &getUrl)> callback = std::function<void(const QString &getUrl)>());
+
     Jid realJid(const Jid &j) const;
     PsiContact* selfContact() const;
     const QList<PsiContact*>& contactList() const;
