@@ -152,7 +152,7 @@ public slots:
 
     void lastactivity_finished()
     {
-        LastActivityTask *idle = (LastActivityTask *)sender();
+        LastActivityTask *idle = static_cast<LastActivityTask *>(sender());
 
         if (!idle->success()) {
             dlg_->appendSysMsg("Could not determine time of last activity.");
@@ -183,9 +183,6 @@ PsiChatDlg::PsiChatDlg(const Jid& jid, PsiAccount* pa, TabManager* tabManager)
     connect(account(), SIGNAL(removedContact(PsiContact*)), SLOT(updateContactAdding(PsiContact*)));
     connect(account(), SIGNAL(updateContact(const Jid &)), SLOT(updateContactAdding(const Jid &)));
     mCmdManager_.registerProvider(new ChatDlgMCmdProvider(this));
-    tabmode = PsiOptions::instance()->getOption("options.ui.tabs.use-tabs").toBool();
-    setWindowBorder(PsiOptions::instance()->getOption("options.ui.decorate-windows").toBool());
-
     SendButtonTemplatesMenu* menu = getTemplateMenu();
     if (menu) {
         connect(menu, SIGNAL(doPasteAndSend()), this, SLOT(doPasteAndSend()));
@@ -286,11 +283,7 @@ void PsiChatDlg::initUi()
     act_mini_cmd_->setText(tr("Input command..."));
     connect(act_mini_cmd_, SIGNAL(triggered()), SLOT(doMiniCmd()));
     addAction(act_mini_cmd_);
-    if (!tabmode) {
-        winHeader_ = new PsiWindowHeader(this);
-        ui_.vboxLayout1->insertWidget(0, winHeader_);
-    }
-    setMargins();
+
     connect(ui_.log->textWidget(), SIGNAL(quote(const QString &)), ui_.mle->chatEdit(), SLOT(insertAsQuote(const QString &)));
 
     act_pastesend_ = new IconAction(tr("Paste and Send"), "psi/action_paste_and_send", tr("Paste and Send"), 0, this);
@@ -599,22 +592,6 @@ void PsiChatDlg::activated()
     ChatDlg::activated();
 
     updateCountVisibility();
-
-    bool border = PsiOptions::instance()->getOption("options.ui.decorate-windows").toBool();
-    if (!PsiOptions::instance()->getOption("options.ui.tabs.use-tabs").toBool()){
-        if (!winHeader_.isNull())
-            winHeader_->setVisible(!border);
-        setWindowBorder(border);
-        setMargins();
-#if defined(Q_OS_MAC) || defined(Q_WS_HAIKU)
-        //
-#else
-        bringToFront(true);
-#endif
-    } else {
-        if (!winHeader_.isNull())
-            winHeader_->setVisible(false);
-    }
 }
 
 void PsiChatDlg::setContactToolTip(QString text)
@@ -962,7 +939,8 @@ bool PsiChatDlg::isEncryptionEnabled() const
 
 void PsiChatDlg::appendSysMsg(const QString &str)
 {
-    dispatchMessage(MessageView::fromHtml(str, MessageView::System));
+    MessageView mv = MessageView::systemMessage(str);
+    dispatchMessage(mv);
 }
 
 ChatView* PsiChatDlg::chatView() const
@@ -1059,7 +1037,7 @@ void PsiChatDlg::addContact()
 bool PsiChatDlg::eventFilter( QObject *obj, QEvent *ev ) {
     if ( obj == chatEdit() ) {
         if ( ev->type() == QEvent::KeyPress ) {
-            QKeyEvent *e = (QKeyEvent *)ev;
+            QKeyEvent *e = static_cast<QKeyEvent *>(ev);
 
             if ( e->key() == Qt::Key_Tab ) {
                 tabCompletion.tryComplete();
@@ -1155,23 +1133,4 @@ void PsiChatDlg::doSwitchJidMode()
     }
 }
 
-void PsiChatDlg::setMargins()
-{
-    ui_.vboxLayout->setContentsMargins(0,0,0,0);
-    ui_.vboxLayout2->setContentsMargins(4,0,4,4);
-    if (!tabmode) {
-        ui_.hboxLayout->setContentsMargins(4,0,4,0);
-        if (!isBorder()) {
-            ui_.vboxLayout1->setContentsMargins(0,0,0,0);
-        }
-        else {
-            ui_.vboxLayout1->setContentsMargins(0,4,0,0);
-        }
-    }
-    else {
-        ui_.vboxLayout1->setContentsMargins(4,4,4,0);
-        ui_.hboxLayout->setContentsMargins(2,0,4,0);
-    }
-}
-
 #include "psichatdlg.moc"
