@@ -62,7 +62,7 @@
 #ifdef HAVE_PGPUTIL
 #include "pgputil.h"
 #endif
-#include "edbflatfile.h"
+#include "edbsqlite.h"
 #include "proxy.h"
 #ifdef PSIMNG
 #include "psimng.h"
@@ -123,8 +123,6 @@
 #include "AutoUpdater/AutoUpdater.h"
 #ifdef HAVE_SPARKLE
 #include "AutoUpdater/SparkleAutoUpdater.h"
-#elif defined(USE_QDCHECKER)
-#    include "AutoUpdater/QDChecker.h"
 #endif
 
 #ifdef Q_OS_MAC
@@ -221,17 +219,11 @@ class PsiCon::Private : public QObject
 {
     Q_OBJECT
 public:
-    Private(PsiCon *parent)
-        : QObject(parent)
-        , contactList(0)
-        , iconSelect(0)
-        , quitting(false)
-        , wakeupPending(false)
-        , alertManager(parent)
-        , bossKey(0)
-        , popupManager(0)
+    Private(PsiCon *parent) :
+        QObject(parent),
+        psi(parent),
+        alertManager(parent)
     {
-        psi = parent;
     }
 
     ~Private()
@@ -285,41 +277,40 @@ private slots:
     }
 
 public:
-    PsiCon* psi;
-    PsiContactList* contactList;
+    PsiCon *psi = nullptr;
+    PsiContactList *contactList = nullptr;
     OptionsMigration optionsMigration;
     OptionsTree accountTree;
-    MainWin *mainwin;
+    MainWin *mainwin = nullptr;
     Idle idle;
     QList<item_dialog*> dialogList;
-    int eventId;
+    int eventId = 0;
     QStringList recentNodeList; // FIXME move this to options system?
-    EDB *edb;
-    S5BServer *s5bServer;
-    IconSelectPopup *iconSelect;
-    NetworkAccessManager *nam;
+    EDB *edb = nullptr;
+    S5BServer *s5bServer = nullptr;
+    IconSelectPopup *iconSelect = nullptr;
+    NetworkAccessManager *nam = nullptr;
 #ifdef FILETRANSFER
-    FileTransDlg *ftwin;
+    FileTransDlg *ftwin = nullptr;
 #endif
-    PsiActionList *actionList;
+    PsiActionList *actionList = nullptr;
     //GlobalAccelManager *globalAccelManager;
-    TuneControllerManager* tuneManager;
-    QMenuBar* defaultMenuBar;
-    TabManager *tabManager;
-    bool quitting;
-    bool wakeupPending;
-    QTimer* updatedAccountTimer_;
-    AutoUpdater *autoUpdater;
+    TuneControllerManager* tuneManager = nullptr;
+    QMenuBar* defaultMenuBar = nullptr;
+    TabManager *tabManager = nullptr;
+    bool quitting = false;
+    bool wakeupPending = false;
+    QTimer *updatedAccountTimer_ = nullptr;
+    AutoUpdater *autoUpdater = nullptr;
     AlertManager alertManager;
-    BossKey *bossKey;
-    PopupManager * popupManager;
+    BossKey *bossKey = nullptr;
+    PopupManager * popupManager = nullptr;
     QNetworkConfigurationManager netConfMng;
     QNetworkSession *netSession = nullptr;
 
     struct IdleSettings
     {
-        IdleSettings() : secondsIdle(0)
-        {}
+        IdleSettings() = default;
 
         void update()
         {
@@ -334,10 +325,10 @@ public:
             useIdleServer = o->getOption("options.service-discovery.last-activity").toBool();
         }
 
-        bool useOffline, useNotAvailable, useAway, menuXA;
-        int offlineAfter, notAvailableAfter, awayAfter;
-        int secondsIdle;
-        bool useIdleServer;
+        bool useOffline = false, useNotAvailable = false, useAway = false, menuXA = false;
+        int offlineAfter = 0, notAvailableAfter = 0, awayAfter = 0;
+        int secondsIdle = 0;
+        bool useIdleServer = false;
     };
 
     IdleSettings idleSettings_;
@@ -348,27 +339,15 @@ public:
 //----------------------------------------------------------------------------
 
 PsiCon::PsiCon()
-    : QObject(0)
+    : QObject(nullptr)
 {
-    //pdb(DEBUG_JABCON, QString("%1 v%2\n By Justin Karneges\n    infiniti@affinix.com\n\n").arg(PROG_NAME).arg(PROG_VERSION));
+    //pdb(DEBUG_JABCON, QString("%1 v%2\n By Justin Karneges\n    justin@karneges.com\n\n").arg(PROG_NAME).arg(PROG_VERSION));
     d = new Private(this);
     d->tabManager = new TabManager(this);
     connect(QCoreApplication::instance(), SIGNAL(aboutToQuit()), SLOT(aboutToQuit()));
     connect(ProcessQuit::instance(), SIGNAL(quit()), SLOT(aboutToQuit()));
 
-
-    d->mainwin = 0;
-#ifdef FILETRANSFER
-    d->ftwin = 0;
-#endif
-
-    d->edb = 0;
-    d->s5bServer = 0;
-    d->tuneManager = 0;
-    d->autoUpdater = 0;
-
-    d->actionList = 0;
-    d->defaultMenuBar = new QMenuBar(0);
+    d->defaultMenuBar = new QMenuBar(nullptr);
 
     XMPP::CapsRegistry::setInstance(new PsiCapsRegistry(this));
     XMPP::CapsRegistry *pcr = XMPP::CapsRegistry::instance();
@@ -406,9 +385,7 @@ bool PsiCon::init()
     PGPUtil::instance();
 #endif
 
-    d->netSession = new QNetworkSession(d->netConfMng.defaultConfiguration(), this);
-    connect(d->netSession, &QNetworkSession::opened, this, &PsiCon::networkSessionOpened);
-    d->netSession->open();
+    initNetSession();
 
     d->contactList = new PsiContactList(this);
 
@@ -473,6 +450,14 @@ bool PsiCon::init()
     d->tuneManager = new TuneControllerManager();
 #endif
 
+    // Auto updater initialization
+#ifdef HAVE_SPARKLE
+    d->autoUpdater = new SparkleAutoUpdater(ApplicationInfo::getAppCastURL());
+#endif
+    if (d->autoUpdater && options->getOption("options.auto-update.check-on-startup").toBool()) {
+        d->autoUpdater->checkForUpdates();
+    }
+
     // calculate the small font size
     const int minimumFontSize = 7;
     common_smallFontSize = qApp->font().pointSize();
@@ -508,16 +493,7 @@ bool PsiCon::init()
     QDir profileDir( pathToProfile(activeProfile, ApplicationInfo::DataLocation) );
     profileDir.rmdir( "info" ); // remove unused dir
 
-    // Auto updater initialization
-#ifdef HAVE_SPARKLE
-    d->autoUpdater = new SparkleAutoUpdater(ApplicationInfo::getAppCastURL());
-#elif defined(USE_QDCHECKER)
-    d->autoUpdater = new QDChecker();
-#endif
-    if (PsiOptions::instance()->getOption("options.auto-update.check-on-startup").toBool() && d->autoUpdater)
-        d->autoUpdater->checkForUpdates();
-
-    d->iconSelect = new IconSelectPopup(0);
+    d->iconSelect = new IconSelectPopup(nullptr);
     connect(PsiIconset::instance(), SIGNAL(emoticonsChanged()), d, SLOT(updateIconSelect()));
 
     const QString css = options->getOption("options.ui.chat.css").toString();
@@ -529,7 +505,7 @@ bool PsiCon::init()
     if( !PsiIconset::instance()->loadAll() ) {
         //LEGOPTS.iconset = "stellar";
         //if(!is.load(LEGOPTS.iconset)) {
-            QMessageBox::critical(0, tr("Error"), tr("Unable to load iconset!  Please make sure Psi is properly installed."));
+            QMessageBox::critical(nullptr, tr("Error"), tr("Unable to load iconset!  Please make sure Psi is properly installed."));
             result = false;
         //}
     }
@@ -543,7 +519,7 @@ bool PsiCon::init()
 #endif
 
     if( !PsiThemeManager::instance()->loadAll() ) {
-        QMessageBox::critical(0, tr("Error"), tr("Unable to load theme!  Please make sure Psi is properly installed."));
+        QMessageBox::critical(nullptr, tr("Error"), tr("Unable to load theme!  Please make sure Psi is properly installed."));
         result = false;
     }
 
@@ -657,7 +633,13 @@ bool PsiCon::init()
 
     checkAccountsEmpty();
 
-    d->edb = new EDBFlatFile(this);
+    // Import for SQLite history
+    if (d->contactList->defaultAccount()) {
+        EDBSqLite *edb = new EDBSqLite(this);
+        d->edb = edb;
+        if (!edb->init())
+            return false;
+    }
 
     if(d->contactList->defaultAccount())
         emit statusMessageChanged(d->contactList->defaultAccount()->status().status());
@@ -707,7 +689,7 @@ bool PsiCon::init()
 
 bool PsiCon::haveAutoUpdater() const
 {
-    return d->autoUpdater != 0;
+    return d->autoUpdater != nullptr;
 }
 
 void PsiCon::updateStatusPresets()
@@ -735,12 +717,12 @@ void PsiCon::deinit()
 
 #ifdef FILETRANSFER
     delete d->ftwin;
-    d->ftwin = NULL;
+    d->ftwin = nullptr;
 #endif
 
     if(d->mainwin) {
         delete d->mainwin;
-        d->mainwin = 0;
+        d->mainwin = nullptr;
     }
 
     // TuneController
@@ -954,7 +936,7 @@ void PsiCon::doNewBlankMessage()
 EventDlg *PsiCon::createMessageDlg(const QString &to, PsiAccount *pa)
 {
     if (!EventDlg::messagingEnabled())
-        return 0;
+        return nullptr;
 
     return createEventDlg(to, pa);
 }
@@ -1116,7 +1098,7 @@ void PsiCon::statusMenuChanged(XMPP::Status::Type x, bool forceDialog)
             status.setIsInvisible(true);
             break;
         default:
-            status = Status((XMPP::Status::Type)x, "", 0);
+            status = Status(XMPP::Status::Type(x), "", 0);
             break;
         }
         if (o->getOption("options.status.last-overwrite.by-status").toBool()) {
@@ -1217,7 +1199,7 @@ void PsiCon::setStatusMessage(QString message)
 
 void PsiCon::pa_updatedActivity()
 {
-    PsiAccount *pa = (PsiAccount *)sender();
+    PsiAccount *pa = static_cast<PsiAccount *>(sender());
     emit accountUpdated(pa);
 
     // update s5b server
@@ -1228,7 +1210,7 @@ void PsiCon::pa_updatedActivity()
 
 void PsiCon::pa_updatedAccount()
 {
-    PsiAccount *pa = (PsiAccount *)sender();
+    PsiAccount *pa = static_cast<PsiAccount *>(sender());
     emit accountUpdated(pa);
 
     d->updatedAccountTimer_->start();
@@ -1294,11 +1276,7 @@ void PsiCon::checkAccountsEmpty()
 void PsiCon::openUri(const QString &uri)
 {
     QUrl url;
-#ifdef HAVE_QT5
     url.setUrl(uri, QUrl::StrictMode);
-#else
-    url.setEncodedUrl(uri.toLatin1());
-#endif
     openUri(url);
 }
 
@@ -1424,7 +1402,7 @@ void PsiCon::optionChanged(const QString& option)
     if (option == "options.ui.tabs.use-tabs" ||
         option == "options.ui.tabs.grouping" ||
         option == "options.ui.tabs.show-tab-buttons") {
-        QMessageBox::information(0, tr("Information"), tr("Some of the options you changed will only have full effect upon restart."));
+        QMessageBox::information(nullptr, tr("Information"), tr("Some of the options you changed will only have full effect upon restart."));
         //notifyRestart = false;
     }
 
@@ -1486,7 +1464,7 @@ void PsiCon::slotApplyOptions()
 
         // Check whether it is legal to disable the menubar
         if ( !toolbarsVisible ) {
-            QMessageBox::warning(0, tr("Warning"),
+            QMessageBox::warning(nullptr, tr("Warning"),
                 tr("You can not disable <i>all</i> toolbars <i>and</i> the menubar. If you do so, you will be unable to enable them back, when you'll change your mind."),
                 tr("I understand"));
             o->setOption("options.ui.contactlist.show-menubar", true);
@@ -1517,7 +1495,7 @@ void PsiCon::slotApplyOptions()
 
 void PsiCon::queueChanged()
 {
-    PsiIcon *nextAnim = 0;
+    PsiIcon *nextAnim = nullptr;
     int nextAmount = d->contactList->queueCount();
     PsiAccount *pa = d->contactList->queueLowestEventId();
     if(pa)
@@ -1909,6 +1887,38 @@ void PsiCon::doWakeup()
     //setGlobalStatus(Status());
 
     d->wakeupPending = true; // and wait for signal till network session is opened (proved to work on gentoo+nm+xfce)
+
+    QTimer::singleShot(5000, this, SLOT(networkSessionOpened())); // a fallback if QNetworkSession doesn't signal
+    // if 5secs is not enough to connect to the network then it isn't considered a wakeup anymore but a regular reconnect.
+}
+
+void PsiCon::initNetSession()
+{
+    d->netSession = new QNetworkSession(d->netConfMng.defaultConfiguration(), this);
+    connect(d->netSession, &QNetworkSession::opened, this, &PsiCon::networkSessionOpened);
+    connect(d->netSession, &QNetworkSession::closed, this, [this]()
+    {
+        disconnect(d->netSession);
+        d->netSession->deleteLater();
+        initNetSession();
+    });
+    /* next commented out lines could be used for fine-grained control. otherwise forced roaming will be used
+
+    connect(d->netSession, &QNetworkSession::preferredConfigurationChanged, this,
+            [this](const QNetworkConfiguration &config, bool isSeamless)
+    {
+        Q_UNUSED(config)
+        Q_UNUSED(isSeamless)
+
+        d->netSession->migrate();
+    });
+    connect(d->netSession, &QNetworkSession::newConfigurationActivated, this, [this]()
+    {
+        d->netSession->accept();
+        // theoretically psi should catch connection failure on sockets and start reconnecting
+    });
+    */
+    d->netSession->open();
 }
 
 void PsiCon::networkSessionOpened()
