@@ -104,7 +104,7 @@ public:
     void playSound(const QString &);
     bool mainWinVisible() const;
 
-    AccountsComboBox *accountsComboBox(QWidget *parent=0, bool online_only = false);
+    AccountsComboBox *accountsComboBox(QWidget *parent=nullptr, bool online_only = false);
 
     QStringList recentGCList() const;
     void recentGCAdd(const QString &);
@@ -193,6 +193,7 @@ private:
     friend class Private;
     ContactUpdatesManager* contactUpdatesManager_;
 
+    void initNetSession();
     void deleteAllDialogs();
     void s5b_init();
     void updateS5BServerAddresses();
