@@ -89,12 +89,13 @@ public:
 };
 
 PsiPopup::Private::Private(PsiPopup *p)
-    : psi(0)
-    , account(0)
-    , popup(0)
+    : psi(nullptr)
+    , account(nullptr)
+    , popup(nullptr)
     , psiPopup(p)
     , popupType(PopupManager::AlertNone)
-    , titleIcon(0)
+    , titleIcon(nullptr)
+    , display(false)
     , doAlertIcon(false)
 {
 }
@@ -444,7 +445,3 @@ void PsiPopup::deleteAll()
 }
 
 #include "psipopup.moc"
-
-#ifndef HAVE_QT5
-Q_EXPORT_PLUGIN2(psipopup, PsiPopupPlugin)
-#endif
