@@ -62,10 +62,11 @@ public:
 
     virtual void invalidateTab();
 
-    enum State {
-        StateNone = 0,
-        StateComposing,
-        StateHighlighted
+    enum class State : char {
+        None = 0,
+        Composing,
+        Inactive,
+        Highlighted
     };
     virtual State state() const = 0;
     virtual int unreadMessageCount() const = 0;
@@ -98,7 +99,7 @@ protected:
     void changeEvent(QEvent* e);
 
 private:
-    enum ActivationState { Activated, Deactivated };
+    enum class ActivationState : char { Activated, Deactivated };
     ActivationState state_;
     QTimer stateCommitTimer_;
 
