@@ -167,19 +167,9 @@ TabDlg::TabDlg(TabManager* tabManager, const QString& geometryOption, TabDlgDele
         delegate_->tabWidgetCreated(this, tabWidget_);
 
     QVBoxLayout *vert1 = new QVBoxLayout(this);
-    //Add windowheader widget if window not decorated
-    if (!PsiOptions::instance()->getOption("options.ui.decorate-windows").toBool()
-        && !PsiOptions::instance()->getOption("options.ui.tabs.grouping").toString().contains('A')) {
-        winHeader_ = new PsiWindowHeader(this);
-        vert1->addWidget(winHeader_);
-        vert1->setSpacing(0);
-        vert1->setMargin(0);
-    } else {
-        vert1->setMargin(1);
-    }
+    vert1->setMargin(1);
     vert1->addWidget(tabWidget_);
 
-
     setAcceptDrops(true);
 
     X11WM_CLASS("tabs");
@@ -199,7 +189,6 @@ TabDlg::TabDlg(TabManager* tabManager, const QString& geometryOption, TabDlgDele
 
     if(!PsiOptions::instance()->getOption("options.ui.tabs.grouping").toString().contains('A'))
         setGeometryOptionPath(geometryOption);
-    setWindowBorder(PsiOptions::instance()->getOption("options.ui.decorate-windows").toBool());
 }
 
 TabDlg::~TabDlg()
@@ -218,12 +207,6 @@ TabDlg::~TabDlg()
     }
 }
 
-#ifndef HAVE_QT5
-// FIXME: This is a bad idea to store pointers in QMimeData
-Q_DECLARE_METATYPE(TabDlg*);
-Q_DECLARE_METATYPE(TabbableWidget*);
-#endif
-
 void TabDlg::setShortcuts()
 {
     act_close_->setShortcuts(ShortcutManager::instance()->shortcuts("common.close"));
