@@ -35,19 +35,13 @@ class AIMPPlugin : public QObject, public TuneControllerPlugin
     Q_OBJECT
 
     Q_INTERFACES(TuneControllerPlugin)
-#ifdef HAVE_QT5
     Q_PLUGIN_METADATA(IID "org.psi-im.Psi.TuneControllerPlugin")
-#endif
 
 public:
     virtual QString name();
     virtual TuneController* createController();
 };
 
-#ifndef HAVE_QT5
-Q_EXPORT_PLUGIN2(aimpplugin, AIMPPlugin);
-#endif
-
 QString AIMPPlugin::name()
 {
     return "AIMP3";
