@@ -35,18 +35,12 @@ class MPRISPlugin : public QObject, public TuneControllerPlugin
     Q_OBJECT
 
     Q_INTERFACES(TuneControllerPlugin)
-#ifdef HAVE_QT5
     Q_PLUGIN_METADATA(IID "org.psi-im.Psi.TuneControllerPlugin")
-#endif
 public:
     virtual QString name();
     virtual TuneController* createController();
 };
 
-#ifndef HAVE_QT5
-Q_EXPORT_PLUGIN2(mprisplugin, MPRISPlugin);
-#endif
-
 QString MPRISPlugin::name()
 {
     return "MPRIS";
