@@ -31,7 +31,3 @@ TuneController* PsiFilePlugin::createController()
 {
     return new FileTuneController(ApplicationInfo::homeDir(ApplicationInfo::CacheLocation) + "/tune");
 }
-
-#ifndef HAVE_QT5
-Q_EXPORT_PLUGIN2(psifileplugin, PsiFilePlugin);
-#endif
