@@ -52,7 +52,7 @@ static QString dot_truncate(const QString &in, int clip)
 // UserResource
 //----------------------------------------------------------------------------
 UserResource::UserResource()
-:Resource()
+    : v_pgpVerifyStatus(0)
 {
 }
 
@@ -61,10 +61,6 @@ UserResource::UserResource(const Resource &r)
     setResource(r);
 }
 
-UserResource::~UserResource()
-{
-}
-
 void UserResource::setResource(const Resource &r)
 {
     setName(r.name());
