@@ -241,12 +241,12 @@ private:
     Iconset iss;
     QMap<PsiIcon*, QRect> iconRects;
 #endif
-    int w, h;
+    int w = 16, h = 16;
     mutable int fullW, fullH;
 
 public:
     IconsetSelectItem(QListWidget *parent, const Iconset &_iconset)
-    : RealIconWidgetItem(parent)
+        : RealIconWidgetItem(parent)
     {
         Q_UNUSED(fullW)
         Q_UNUSED(fullH)
@@ -427,11 +427,11 @@ private:
 #ifndef WIDGET_PLUGIN
     PsiIcon icon;
 #endif
-    int w, h;
+    int w = 16, h = 16;
 
 public:
     IconsetDisplayItem(QListWidget *parent, PsiIcon *i, int iconW)
-    : RealIconWidgetItem(parent)
+        : RealIconWidgetItem(parent)
     {
 #ifndef WIDGET_PLUGIN
         icon = *i;
@@ -539,9 +539,10 @@ public:
 public:
     Private(IconButton *b)
     {
-        icon = 0;
+        icon = nullptr;
         button = b;
         textVisible = true;
+        activate = false;
         forced = false;
     }
 
@@ -713,8 +714,9 @@ public:
 public:
     Private(IconToolButton *b)
     {
-        icon = 0;
+        icon = nullptr;
         button = b;
+        activate = false;
     }
 
     ~Private()
