@@ -13,26 +13,26 @@ typedef unsigned long Window;
 
 class X11WindowSystem {
 private:
-    Atom net_client_list_stacking;
-    Atom net_frame_extents;
+    Atom net_client_list_stacking = 0ul;
+    Atom net_frame_extents = 0ul;
 
-    Atom net_wm_window_type;
-    Atom net_wm_window_type_normal;
-    Atom net_wm_window_type_dialog;
-    Atom net_wm_window_type_utility;
-    Atom net_wm_window_type_splash;
+    Atom net_wm_window_type = 0ul;
+    Atom net_wm_window_type_normal = 0ul;
+    Atom net_wm_window_type_dialog = 0ul;
+    Atom net_wm_window_type_utility = 0ul;
+    Atom net_wm_window_type_splash = 0ul;
 
-    Atom net_wm_state;
-    Atom net_wm_state_above;
-    Atom net_wm_state_hidden;
+    Atom net_wm_state = 0ul;
+    Atom net_wm_state_above = 0ul;
+    Atom net_wm_state_hidden = 0ul;
 
     QSet<Atom> normalWindows, ignoredWindowStates;
 
     static X11WindowSystem* _instance;
     X11WindowSystem();
     ~X11WindowSystem() {}
-    X11WindowSystem(const X11WindowSystem& ) {};
-    X11WindowSystem & operator=(const X11WindowSystem &) {return *this;};
+    X11WindowSystem(const X11WindowSystem& ) = default;
+    X11WindowSystem & operator=(const X11WindowSystem &);
 
 public:
     static X11WindowSystem* instance();
