@@ -16,6 +16,8 @@ function initPsiTheme() {
         async : async,
         console : server.console,
         server : server,
+        session : session,
+        hooks: [],
 
         util: {
             console : server.console,
@@ -407,12 +409,90 @@ function initPsiTheme() {
                 }
             }
 
-            //timeout to be sure content rerendered correctly
-            window.addEventListener("resize", function() {setTimeout(function(){
-                if (o.atBottom) { //immediatelly scroll to bottom if we wish it
-                    window.scrollTo(0, document.body.clientHeight - window.innerHeight);
-                }
-            }, 0);}, false);
+            // ensure we at bottom on window resize
+            if (typeof ResizeObserver === 'undefined') {
+
+                // next code is copied from www.backalleycoder.com/2013/03/18/cross-browser-event-based-element-resize-detection/ on 7 Dec 2018
+                (function(){
+                  var attachEvent = document.attachEvent;
+                  var isIE = navigator.userAgent.match(/Trident/);
+                  //console.log(isIE);
+                  var requestFrame = (function(){
+                    var raf = window.requestAnimationFrame || window.mozRequestAnimationFrame || window.webkitRequestAnimationFrame ||
+                        function(fn){ return window.setTimeout(fn, 20); };
+                    return function(fn){ return raf(fn); };
+                  })();
+
+                  var cancelFrame = (function(){
+                    var cancel = window.cancelAnimationFrame || window.mozCancelAnimationFrame || window.webkitCancelAnimationFrame ||
+                           window.clearTimeout;
+                    return function(id){ return cancel(id); };
+                  })();
+
+                  function resizeListener(e){
+                    var win = e.target || e.srcElement;
+                    if (win.__resizeRAF__) cancelFrame(win.__resizeRAF__);
+                    win.__resizeRAF__ = requestFrame(function(){
+                      var trigger = win.__resizeTrigger__;
+                      trigger.__resizeListeners__.forEach(function(fn){
+                        fn.call(trigger, e);
+                      });
+                    });
+                  }
+
+                  function objectLoad(e){
+                    this.contentDocument.defaultView.__resizeTrigger__ = this.__resizeElement__;
+                    this.contentDocument.defaultView.addEventListener('resize', resizeListener);
+                  }
+
+                  window.addResizeListener = function(element, fn){
+                    if (!element.__resizeListeners__) {
+                      element.__resizeListeners__ = [];
+                      if (attachEvent) {
+                        element.__resizeTrigger__ = element;
+                        element.attachEvent('onresize', resizeListener);
+                      }
+                      else {
+                        if (getComputedStyle(element).position == 'static') element.style.position = 'relative';
+                        var obj = element.__resizeTrigger__ = document.createElement('object');
+                        obj.setAttribute('style', 'display: block; position: absolute; top: 0; left: 0; height: 100%; width: 100%; overflow: hidden; pointer-events: none; z-index: -1;');
+                        obj.__resizeElement__ = element;
+                        obj.onload = objectLoad;
+                        obj.type = 'text/html';
+                        if (isIE) element.appendChild(obj);
+                        obj.data = 'about:blank';
+                        if (!isIE) element.appendChild(obj);
+                      }
+                    }
+                    element.__resizeListeners__.push(fn);
+                  };
+
+                  window.removeResizeListener = function(element, fn){
+                    element.__resizeListeners__.splice(element.__resizeListeners__.indexOf(fn), 1);
+                    if (!element.__resizeListeners__.length) {
+                      if (attachEvent) element.detachEvent('onresize', resizeListener);
+                      else {
+                        element.__resizeTrigger__.contentDocument.defaultView.removeEventListener('resize', resizeListener);
+                        element.__resizeTrigger__ = !element.removeChild(element.__resizeTrigger__);
+                      }
+                    }
+                  }
+                })();
+                // end of copied code
+                addResizeListener(document.body, function(){
+                    o.invalidate();
+                });
+            } else {
+                const ro = new ResizeObserver(function(entries) {
+                    o.invalidate();
+                });
+
+                // Observe the scrollingElement for when the window gets resized
+                ro.observe(document.scrollingElement);
+                // Observe the timeline to process new messages
+                // ro.observe(timeline);
+                
+            }
 
             //let's consider scroll may happen only by user action
             window.addEventListener("scroll", function(){
@@ -518,6 +598,14 @@ function initPsiTheme() {
         },
 
         receiveObject : function(data) {
+            for(var i=0; i < chat.hooks.length; i++) {
+                try {
+                    chat.hooks[i](chat, data);
+                } catch (e) {
+                    chat.console("hook failed");
+                }
+            }
+
             if (data.type == "message") {
                 if (data.mtype == "join") {
                     usersMap[data.sender] = {avatar:data.avatar, nickcolor:data.nickcolor, msgs:{}};
@@ -538,6 +626,27 @@ function initPsiTheme() {
                     delete serverTransctions[data.id];
                 }
                 return;
+            } else if (data.type == "receivehooks") {
+                var hooks = [];
+                for (var i = 0; i < data.hooks.length; i++) {
+                    try {
+                        // same chat object as everywhere
+                        var func = new Function("chat, data", data.hooks[i]); /*jshint -W053 */
+                        hooks.push(func);
+                    } catch(e) {
+                        server.console("Failed to evalute receive hook: " + e + "\n" + data.hooks[i]);
+                    }
+                }
+                chat.hooks = hooks;
+            } else if (data.type == "js") {
+                try {
+                    //server.console("An attempt to execute: " + data.js);
+                    // same chat object as everywhere
+                    var func = new Function("chat", data.js); /*jshint -W053 */
+                    func(chat);
+                } catch(e) {
+                    server.console("Failed to evalute/execute js: " + e + "\n" + data.js);
+                }
             }
 
             chat.adapter.receiveObject(data)
